@@ -3,7 +3,7 @@
     Smb4K.
                              -------------------
     begin                : Do Apr 2 2009
-    copyright            : (C) 2009-2017 by Alexander Reinholdt
+    copyright            : (C) 2009-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -34,6 +34,7 @@
 #include <QString>
 #include <QScopedPointer>
 #include <QIcon>
+#include <QUrl>
 
 // forward declarations
 class Smb4KBasicNetworkItemPrivate;
@@ -88,6 +89,31 @@ class Q_DECL_EXPORT Smb4KBasicNetworkItem
      */
     QIcon icon() const;
     
+    /**
+     * Set the URL for this network item.
+     * 
+     * @param url           The URL
+     */
+    void setUrl(const QUrl &url);
+    
+    /**
+     * Return the URL for this network item.
+     * 
+     * @returns the URL
+     */
+    QUrl url() const;
+    
+  protected:
+    /**
+     * Expose a pointer to the private URL variable.
+     */
+    QUrl *pUrl;
+    
+    /**
+     * Export a pointer to the private icon variable.
+     */
+    QIcon *pIcon;
+    
   private:
     const QScopedPointer<Smb4KBasicNetworkItemPrivate> d;
 };
