@@ -2,7 +2,7 @@
     This class handles the bookmarks.
                              -------------------
     begin                : Fr Jan 9 2004
-    copyright            : (C) 2004-2017 by Alexander Reinholdt
+    copyright            : (C) 2004-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -48,6 +48,7 @@
 #include <QXmlStreamReader>
 #include <QPointer>
 #include <QMutableListIterator>
+#include <QApplication>
 
 // KDE includes
 #define TRANSLATION_DOMAIN "smb4k-core"
@@ -64,10 +65,9 @@ Q_GLOBAL_STATIC(Smb4KBookmarkHandlerStatic, p);
 Smb4KBookmarkHandler::Smb4KBookmarkHandler(QObject *parent)
 : QObject(parent), d(new Smb4KBookmarkHandlerPrivate)
 {
-  // Bookmark editor
-  d->editor = 0;
-  
+  // 
   // First we need the directory.
+  // 
   QString path = dataLocation();
   
   QDir dir;
@@ -76,12 +76,16 @@ Smb4KBookmarkHandler::Smb4KBookmarkHandler(QObject *parent)
   {
     dir.mkpath(path);
   }
-  else
-  {
-    // Do nothing
-  }
 
-  readBookmarks();
+  //
+  // Read the list of bookmarks
+  // 
+  readBookmarkList();
+  
+  //
+  // Init the bookmark editor
+  // 
+  d->editor = 0;
 }
 
 
@@ -91,8 +95,6 @@ Smb4KBookmarkHandler::~Smb4KBookmarkHandler()
   {
     d->bookmarks.takeFirst().clear();
   }
-  
-  delete d->editor;
 }
 
 
@@ -102,22 +104,18 @@ Smb4KBookmarkHandler *Smb4KBookmarkHandler::self()
 }
 
 
-void Smb4KBookmarkHandler::addBookmark(const SharePtr &share, QWidget *parent)
+void Smb4KBookmarkHandler::addBookmark(const SharePtr &share)
 {
   if (share)
   {
     QList<SharePtr> shares;
     shares << share;
-    addBookmarks(shares, parent);
-  }
-  else
-  {
-    // Do nothing
+    addBookmarks(shares);
   }
 }
 
 
-void Smb4KBookmarkHandler::addBookmarks(const QList<SharePtr> &list, QWidget *parent)
+void Smb4KBookmarkHandler::addBookmarks(const QList<SharePtr> &list)
 {
   //
   // Prepare the list of bookmarks that should be added
@@ -134,45 +132,26 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<SharePtr> &list, QWidget *pa
       Smb4KNotification::cannotBookmarkPrinter(share);
       continue;
     }
-    else
-    {
-      // Do nothing
-    }
     
     //
     // Process homes shares
     //
-    if (share->isHomesShare())
+    if (share->isHomesShare() && !Smb4KHomesSharesHandler::self()->specifyUser(share, true))
     {
-      if (!Smb4KHomesSharesHandler::self()->specifyUser(share, true, parent))
-      {
-        continue;
-      }
-      else
-      {
-        // Do nothing
-      }
-    }
-    else
-    {
-      // Do nothing
+      continue;
     }
     
     //
     // Check if the share has already been bookmarked and skip it if it
     // already exists
     //
-    BookmarkPtr knownBookmark = findBookmarkByUNC(share->isHomesShare() ? share->homeUNC() : share->unc());
+    BookmarkPtr knownBookmark = findBookmarkByUrl(share->isHomesShare() ? share->homeUrl() : share->url());
     
     if (knownBookmark)
     {
       Smb4KNotification::bookmarkExists(knownBookmark.data());
       continue;
     }
-    else
-    {
-      // Do nothing
-    }
     
     BookmarkPtr bookmark = BookmarkPtr(new Smb4KBookmark(share.data()));
     bookmark->setProfile(Smb4KProfileManager::self()->activeProfile());
@@ -184,7 +163,7 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<SharePtr> &list, QWidget *pa
   //
   if (!newBookmarks.isEmpty())
   {
-    QPointer<Smb4KBookmarkDialog> dlg = new Smb4KBookmarkDialog(newBookmarks, groupsList(), parent);
+    QPointer<Smb4KBookmarkDialog> dlg = new Smb4KBookmarkDialog(newBookmarks, groupsList(), QApplication::activeWindow());
     
     if (dlg->exec() == QDialog::Accepted)
     {
@@ -193,17 +172,9 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<SharePtr> &list, QWidget *pa
       // above.
       addBookmarks(dlg->bookmarks(), false);
     }
-    else
-    {
-      // Do nothing
-    }
     
     delete dlg;
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // Clear the temporary list of bookmarks
@@ -234,18 +205,10 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<BookmarkPtr> &list, bool rep
       {
         continue;
       }
-      else
-      {
-        // Do nothing
-      }
       
       it.remove();
     }
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // Copy all bookmarks that are not in the list
@@ -260,15 +223,11 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<BookmarkPtr> &list, bool rep
       Smb4KNotification::bookmarkLabelInUse(bookmark.data());
       bookmark->setLabel(QString("%1 (1)").arg(bookmark->label()));
     }
-    else
-    {
-      // Do nothing
-    }
       
     //
     // Check if we have to add the bookmark
     // 
-    BookmarkPtr existingBookmark = findBookmarkByUNC(bookmark->unc());
+    BookmarkPtr existingBookmark = findBookmarkByUrl(bookmark->url());
       
     if (!existingBookmark)
     {
@@ -276,7 +235,7 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<BookmarkPtr> &list, bool rep
     }
     else
     {
-      // We do not to update the bookmark, because we are
+      // We do not need to update the bookmark, because we are
       // operating on a shared pointer.
     }
   }
@@ -296,26 +255,20 @@ void Smb4KBookmarkHandler::removeBookmark(const BookmarkPtr &bookmark)
     for (int i = 0; i < d->bookmarks.size(); ++i)
     {
       if ((!Smb4KSettings::useProfiles() || Smb4KSettings::activeProfile() == d->bookmarks.at(i)->profile()) &&
-          QString::compare(bookmark->unc(), d->bookmarks.at(i)->unc(), Qt::CaseInsensitive) == 0 &&
+          QString::compare(d->bookmarks.at(i)->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
+                           bookmark->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
+                           Qt::CaseInsensitive) == 0 &&
           QString::compare(bookmark->groupName(), d->bookmarks.at(i)->groupName(), Qt::CaseInsensitive) == 0)
       {
         d->bookmarks.takeAt(i).clear();
         break;
       }
-      else
-      {
-        // Do nothing
-      }
     }
     
     // Write the list to the bookmarks file.
     writeBookmarkList();
     emit updated();
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -332,10 +285,6 @@ void Smb4KBookmarkHandler::removeGroup(const QString& name)
     {
       it.remove();
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   // Write the list to the bookmarks file.
@@ -356,7 +305,7 @@ void Smb4KBookmarkHandler::writeBookmarkList()
       xmlWriter.setAutoFormatting(true);
       xmlWriter.writeStartDocument();
       xmlWriter.writeStartElement("bookmarks");
-      xmlWriter.writeAttribute("version", "1.1");
+      xmlWriter.writeAttribute("version", "2.0");
 
       for (const BookmarkPtr &bookmark : d->bookmarks)
       {
@@ -365,20 +314,15 @@ void Smb4KBookmarkHandler::writeBookmarkList()
           Smb4KNotification::invalidURLPassed();
           continue;
         }
-        else
-        {
-          // Do nothing
-        }
-
+        
         xmlWriter.writeStartElement("bookmark");
         xmlWriter.writeAttribute("profile", bookmark->profile());
         xmlWriter.writeAttribute("group", bookmark->groupName());
 
         xmlWriter.writeTextElement("workgroup", bookmark->workgroupName());
-        xmlWriter.writeTextElement("unc", bookmark->unc());
+        xmlWriter.writeTextElement("url", bookmark->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort));
         xmlWriter.writeTextElement("login", bookmark->login());
-        xmlWriter.writeTextElement("ip", bookmark->hostIP());
-        xmlWriter.writeTextElement("type", bookmark->typeString());
+        xmlWriter.writeTextElement("ip", bookmark->hostIpAddress());
         xmlWriter.writeTextElement("label", bookmark->label());
 
         xmlWriter.writeEndElement();
@@ -400,7 +344,7 @@ void Smb4KBookmarkHandler::writeBookmarkList()
 }
 
 
-void Smb4KBookmarkHandler::readBookmarks()
+void Smb4KBookmarkHandler::readBookmarkList()
 {
   //
   // Clear the list of bookmarks
@@ -409,8 +353,10 @@ void Smb4KBookmarkHandler::readBookmarks()
   {
     d->bookmarks.takeFirst().clear();
   }
-
-  // Locate the XML file.
+  
+  // 
+  // Locate the XML file and read the bookmarks
+  // 
   QFile xmlFile(dataLocation()+QDir::separator()+"bookmarks.xml");
 
   if (xmlFile.open(QIODevice::ReadOnly | QIODevice::Text))
@@ -423,8 +369,8 @@ void Smb4KBookmarkHandler::readBookmarks()
 
       if (xmlReader.isStartElement())
       {
-        if (xmlReader.name() == "bookmarks" &&
-             (xmlReader.attributes().value("version") != "1.0" && xmlReader.attributes().value("version") != "1.1"))
+        if (xmlReader.name() == "bookmarks" && 
+            (xmlReader.attributes().value("version") != "1.1" && xmlReader.attributes().value("version") != "2.0"))
         {
           xmlReader.raiseError(i18n("The format of %1 is not supported.", xmlFile.fileName()));
           break;
@@ -451,7 +397,11 @@ void Smb4KBookmarkHandler::readBookmarks()
                 }
                 else if (xmlReader.name() == "unc")
                 {
-                  bookmark->setURL(xmlReader.readElementText());
+                  bookmark->setUrl(xmlReader.readElementText());
+                }
+                else if (xmlReader.name() == "url")
+                {
+                  bookmark->setUrl(QUrl(xmlReader.readElementText()));
                 }
                 else if (xmlReader.name() == "login")
                 {
@@ -459,20 +409,12 @@ void Smb4KBookmarkHandler::readBookmarks()
                 }
                 else if (xmlReader.name() == "ip")
                 {
-                  bookmark->setHostIP(xmlReader.readElementText());
-                }
-                else if (xmlReader.name() == "type")
-                {
-                  bookmark->setTypeString(xmlReader.readElementText());
+                  bookmark->setHostIpAddress(xmlReader.readElementText());
                 }
                 else if (xmlReader.name() == "label")
                 {
                   bookmark->setLabel(xmlReader.readElementText());
                 }
-                else
-                {
-                  // Do nothing
-                }
 
                 continue;
               }
@@ -502,10 +444,6 @@ void Smb4KBookmarkHandler::readBookmarks()
     {
       Smb4KNotification::readingFileFailed(xmlFile, xmlReader.errorString());
     }
-    else
-    {
-      // Do nothing
-    }
   }
   else
   {
@@ -513,17 +451,13 @@ void Smb4KBookmarkHandler::readBookmarks()
     {
       Smb4KNotification::openingFileFailed(xmlFile);
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   emit updated();
 }
 
 
-BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUNC(const QString &unc)
+BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUrl(const QUrl &url)
 {
   // Update the bookmarks:
   update();
@@ -531,16 +465,17 @@ BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUNC(const QString &unc)
   // Find the bookmark:
   BookmarkPtr bookmark;
 
-  for (const BookmarkPtr &b : bookmarksList())
+  if (!url.isEmpty() && url.isValid() && !bookmarksList().isEmpty())
   {
-    if (QString::compare(b->unc().toUpper(), unc.toUpper()) == 0)
+    for (const BookmarkPtr &b : bookmarksList())
     {
-      bookmark = b;
-      break;
-    }
-    else
-    {
-      continue;
+      if (QString::compare(b->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
+                           url.toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
+                           Qt::CaseInsensitive) == 0)
+      {
+        bookmark = b;
+        break;
+      }
     }
   }
 
@@ -589,18 +524,10 @@ QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList() const
       {
         bookmarks << b;
       }
-      else
-      {
-        // Do nothing
-      }
     }
     
     return bookmarks;
   }
-  else
-  {
-    // Do nothing
-  }
   
   // Return the list of bookmarks:
   return d->bookmarks;
@@ -621,10 +548,6 @@ QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList(const QString &group) con
     {
       bookmarks << bookmark;
     }
-    else
-    {
-      // Do nothing
-    }
   }
 
   return bookmarks;
@@ -641,21 +564,37 @@ QStringList Smb4KBookmarkHandler::groupsList() const
     {
       groups << b->groupName();
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   return groups;
 }
 
 
-void Smb4KBookmarkHandler::editBookmarks(QWidget *parent)
+void Smb4KBookmarkHandler::resetBookmarks()
 {
+  readBookmarkList();
+}
+
+
+bool Smb4KBookmarkHandler::isBookmarked(const SharePtr& share)
+{
+  if (findBookmarkByUrl(share->url()))
+  {
+    return true;
+  }
+  
+  return false;
+}
+
+
+void Smb4KBookmarkHandler::editBookmarks()
+{
+  //
+  // Only allow one instance of the bookmark editor
+  // 
   if (!d->editor)
   {
-    d->editor = new Smb4KBookmarkEditor(d->bookmarks, parent);
+    d->editor = new Smb4KBookmarkEditor(bookmarksList(), QApplication::activeWindow());
   }
   else
   {
@@ -664,25 +603,21 @@ void Smb4KBookmarkHandler::editBookmarks(QWidget *parent)
   
   if (d->editor->exec() == QDialog::Accepted)
   {
-    QList<BookmarkPtr> bookmarks = d->editor->editedBookmarks();
-    addBookmarks(bookmarks, true);
+    addBookmarks(d->editor->editedBookmarks(), true);
   }
   else
   {
     resetBookmarks();
   }
-
+  
+  //
+  // Delete the editor after use
+  // 
   delete d->editor;
   d->editor = 0;
 }
 
 
-void Smb4KBookmarkHandler::resetBookmarks()
-{
-  readBookmarks();
-}
-
-
 void Smb4KBookmarkHandler::update() const
 {
   // Get new IP addresses.
@@ -692,18 +627,10 @@ void Smb4KBookmarkHandler::update() const
     
     if (host)
     {
-      if (host->hasIP() && bookmark->hostIP() != host->ip())
+      if (host->hasIpAddress() && bookmark->hostIpAddress() != host->ipAddress())
       {
-        bookmark->setHostIP(host->ip());
+        bookmark->setHostIpAddress(host->ipAddress());
       }
-      else
-      {
-        // Do nothing
-      }
-    }
-    else
-    {
-      // Do nothing
     }
   }
 }
@@ -718,10 +645,6 @@ void Smb4KBookmarkHandler::migrateProfile(const QString& from, const QString& to
     {
       bookmark->setProfile(to);
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   // Write the new list to the file.
@@ -741,10 +664,6 @@ void Smb4KBookmarkHandler::removeProfile(const QString& name)
     {
       it.remove();
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   // Write the new list to the file.
