@@ -2,7 +2,7 @@
     Private classes for the bookmark handler
                              -------------------
     begin                : Sun Mar 20 2011
-    copyright            : (C) 2011-2017 by Alexander Reinholdt
+    copyright            : (C) 2011-2018 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -49,6 +49,7 @@
 #include <QDragMoveEvent>
 #include <QDragEnterEvent>
 #include <QDragLeaveEvent>
+#include <QWindow>
 
 // KDE includes
 #define TRANSLATION_DOMAIN "smb4k-core"
@@ -60,16 +61,50 @@
 Smb4KBookmarkDialog::Smb4KBookmarkDialog(const QList<BookmarkPtr> &bookmarks, const QStringList &groups, QWidget *parent)
 : QDialog(parent)
 {
+  //
+  // Set the window title
+  // 
   setWindowTitle(i18n("Add Bookmarks"));
 
+  //
+  // Setup the view
+  // 
   setupView();
+  
+  //
+  // Load the list of bookmarks and groups
+  // 
   loadLists(bookmarks, groups);
 
+  //
+  // Set the dialog size
+  // 
+  create();
+
   KConfigGroup group(Smb4KSettings::self()->config(), "BookmarkDialog");
-  KWindowConfig::restoreWindowSize(windowHandle(), group);
+  QSize dialogSize;
+  
+  if (group.exists())
+  {
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    dialogSize = windowHandle()->size();
+  }
+  else
+  {
+    dialogSize = sizeHint();
+  }
+  
+  resize(dialogSize); // workaround for QTBUG-40584
+
+  //
+  // Fill the completion objects
+  // 
   m_label_edit->completionObject()->setItems(group.readEntry("LabelCompletion", QStringList()));
   m_group_combo->completionObject()->setItems(group.readEntry("GroupCompletion", m_groups));
 
+  //
+  // Connections
+  // 
   connect(KIconLoader::global(), SIGNAL(iconChanged(int)), SLOT(slotIconSizeChanged(int)));
 }
 
@@ -128,7 +163,7 @@ void Smb4KBookmarkDialog::setupView()
 
   QLabel *l_label = new QLabel(i18n("Label:"), m_editors);
   m_label_edit = new KLineEdit(m_editors);
-  m_label_edit->setClearButtonShown(true);
+  m_label_edit->setClearButtonEnabled(true);
 
   QLabel *g_label = new QLabel(i18n("Group:"), m_editors);
   m_group_combo = new KComboBox(true, m_editors);
@@ -152,22 +187,14 @@ void Smb4KBookmarkDialog::setupView()
   layout->addWidget(m_editors, 0);
   layout->addWidget(buttonBox, 0);
 
-  setMinimumWidth(sizeHint().width() > 350 ? sizeHint().width() : 350);
-
-  connect(m_widget, SIGNAL(itemClicked(QListWidgetItem*)), 
-          this, SLOT(slotBookmarkClicked(QListWidgetItem*)));
-  
-  connect(m_label_edit, SIGNAL(editingFinished()), 
-          this, SLOT(slotLabelEdited()));
-  
-  connect(m_group_combo->lineEdit(), SIGNAL(editingFinished()), 
-          this, SLOT(slotGroupEdited()));
-  
-  connect(m_ok_button, SIGNAL(clicked()), 
-          this, SLOT(slotDialogAccepted()));
-  
-  connect(m_cancel_button, SIGNAL(clicked()), 
-          this, SLOT(reject()));
+  //
+  // Connections
+  // 
+  connect(m_widget, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(slotBookmarkClicked(QListWidgetItem*)));
+  connect(m_label_edit, SIGNAL(editingFinished()), this, SLOT(slotLabelEdited()));
+  connect(m_group_combo->lineEdit(), SIGNAL(editingFinished()), this, SLOT(slotGroupEdited()));
+  connect(m_ok_button, SIGNAL(clicked()), this, SLOT(slotDialogAccepted()));
+  connect(m_cancel_button, SIGNAL(clicked()), this, SLOT(reject()));
 }
 
 
@@ -177,7 +204,7 @@ void Smb4KBookmarkDialog::loadLists(const QList<BookmarkPtr> &bookmarks, const Q
   // the list widget afterwards.
   for (const BookmarkPtr &b : bookmarks)
   {
-    QListWidgetItem *item = new QListWidgetItem(b->icon(), b->unc(), m_widget);
+    QListWidgetItem *item = new QListWidgetItem(b->icon(), b->displayString(), m_widget);
     item->setData(Qt::UserRole, static_cast<QUrl>(b->url()));
     
     m_bookmarks << b;
@@ -218,10 +245,6 @@ void Smb4KBookmarkDialog::slotBookmarkClicked(QListWidgetItem *bookmark_item)
     {
       m_editors->setEnabled(true);
     }
-    else
-    {
-      // Do nothing
-    }
 
     QUrl url = bookmark_item->data(Qt::UserRole).toUrl();
     
@@ -259,10 +282,6 @@ void Smb4KBookmarkDialog::slotLabelEdited()
   {
     bookmark->setLabel(m_label_edit->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 
   // Add label to completion object
   KCompletion *completion = m_label_edit->completionObject();
@@ -271,10 +290,6 @@ void Smb4KBookmarkDialog::slotLabelEdited()
   {
     completion->addItem(m_label_edit->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -289,20 +304,12 @@ void Smb4KBookmarkDialog::slotGroupEdited()
   {
     bookmark->setGroupName(m_group_combo->currentText());
   }
-  else
-  {
-    // Do nothing
-  }
 
   // Add the group name to the combo box
   if (m_group_combo->findText(m_group_combo->currentText()) == -1)
   {
     m_group_combo->addItem(m_group_combo->currentText());
   }
-  else
-  {
-    // Do nothing
-  }
 
   // Add group to completion object
   KCompletion *completion = m_group_combo->completionObject();
@@ -311,10 +318,6 @@ void Smb4KBookmarkDialog::slotGroupEdited()
   {
     completion->addItem(m_group_combo->currentText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -347,24 +350,55 @@ void Smb4KBookmarkDialog::slotIconSizeChanged(int group)
 }
 
 
-
 Smb4KBookmarkEditor::Smb4KBookmarkEditor(const QList<BookmarkPtr> &bookmarks, QWidget *parent)
 : QDialog(parent), m_bookmarks(bookmarks)
 {
+  //
+  // Set the window title
+  // 
   setWindowTitle(i18n("Edit Bookmarks"));
   
+  //
+  // Setup the view
+  // 
   setupView();
+  
+  //
+  // Load the bookmarks into the editor
+  // 
   loadBookmarks();
 
-  setMinimumWidth(sizeHint().height() > sizeHint().width() ? sizeHint().height() : sizeHint().width());
+  //
+  // Set the dialog size
+  // 
+  create();
 
   KConfigGroup group(Smb4KSettings::self()->config(), "BookmarkEditor");
-  KWindowConfig::restoreWindowSize(windowHandle(), group);
+  QSize dialogSize;
+  
+  if (group.exists())
+  {
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    dialogSize = windowHandle()->size();
+  }
+  else
+  {
+    dialogSize = sizeHint();
+  }
+  
+  resize(dialogSize); // workaround for QTBUG-40584
+  
+  //
+  // Fill the completion objects
+  // 
   m_label_edit->completionObject()->setItems(group.readEntry("LabelCompletion", QStringList()));
   m_login_edit->completionObject()->setItems(group.readEntry("LoginCompletion", QStringList()));
   m_ip_edit->completionObject()->setItems(group.readEntry("IPCompletion", QStringList()));
   m_group_combo->completionObject()->setItems(group.readEntry("GroupCompletion", m_groups));
 
+  //
+  // Connections
+  // 
   connect(KIconLoader::global(), SIGNAL(iconChanged(int)), SLOT(slotIconSizeChanged(int)));
 }
 
@@ -378,12 +412,6 @@ Smb4KBookmarkEditor::~Smb4KBookmarkEditor()
 }
 
 
-QList<BookmarkPtr> Smb4KBookmarkEditor::editedBookmarks() const
-{
-  return m_bookmarks;
-}
-
-
 bool Smb4KBookmarkEditor::eventFilter(QObject *obj, QEvent *e)
 {
   if (obj == m_tree_widget->viewport())
@@ -443,9 +471,9 @@ void Smb4KBookmarkEditor::setupView()
   m_tree_widget->setIconSize(QSize(icon_size, icon_size));
   m_tree_widget->viewport()->installEventFilter(this);
 
-  m_add_group = new QAction(KDE::icon("folder-bookmark"), i18n("Add Group"), m_tree_widget);
+  m_add_group = new QAction(KDE::icon("bookmark-add-folder"), i18n("Add Group"), m_tree_widget);
   m_delete = new QAction(KDE::icon("edit-delete"), i18n("Remove"), m_tree_widget);
-  m_clear = new QAction(KDE::icon("edit-clear"), i18n("Clear Bookmarks"), m_tree_widget);
+  m_clear = new QAction(KDE::icon("edit-clear"), i18n("Clear"), m_tree_widget);
   
   m_menu = new KActionMenu(m_tree_widget);
   m_menu->addAction(m_add_group);
@@ -461,15 +489,15 @@ void Smb4KBookmarkEditor::setupView()
 
   QLabel *l_label = new QLabel(i18n("Label:"), m_editors);
   m_label_edit = new KLineEdit(m_editors);
-  m_label_edit->setClearButtonShown(true);
+  m_label_edit->setClearButtonEnabled(true);
 
   QLabel *lg_label = new QLabel(i18n("Login:"), m_editors);
   m_login_edit = new KLineEdit(m_editors);
-  m_login_edit->setClearButtonShown(true);
+  m_login_edit->setClearButtonEnabled(true);
 
   QLabel *i_label = new QLabel(i18n("IP Address:"), m_editors);
   m_ip_edit = new KLineEdit(m_editors);
-  m_ip_edit->setClearButtonShown(true);
+  m_ip_edit->setClearButtonEnabled(true);
   
   QLabel *g_label = new QLabel(i18n("Group:"), m_editors);
   m_group_combo = new KComboBox(true, m_editors);
@@ -497,38 +525,20 @@ void Smb4KBookmarkEditor::setupView()
   layout->addWidget(m_editors);
   layout->addWidget(buttonBox);
 
-  connect(m_tree_widget, SIGNAL(itemClicked(QTreeWidgetItem*,int)), 
-          this, SLOT(slotItemClicked(QTreeWidgetItem*,int)));
-  
-  connect(m_tree_widget, SIGNAL(customContextMenuRequested(QPoint)), 
-          this, SLOT(slotContextMenuRequested(QPoint)));
-  
-  connect(m_label_edit, SIGNAL(editingFinished()), 
-          this, SLOT(slotLabelEdited()));
-  
-  connect(m_ip_edit, SIGNAL(editingFinished()), 
-          this, SLOT(slotIPEdited()));
-  
-  connect(m_login_edit, SIGNAL(editingFinished()), 
-          this, SLOT(slotLoginEdited()));
-  
-  connect(m_group_combo->lineEdit(), SIGNAL(editingFinished()), 
-          this, SLOT(slotGroupEdited()));
-  
-  connect(m_add_group, SIGNAL(triggered(bool)), 
-          this, SLOT(slotAddGroupTriggered(bool)));
-  
-  connect(m_delete, SIGNAL(triggered(bool)), 
-          this, SLOT(slotDeleteTriggered(bool)));
-  
-  connect(m_clear, SIGNAL(triggered(bool)), 
-          this, SLOT(slotClearTriggered(bool)));
-  
-  connect(m_ok_button, SIGNAL(clicked()), 
-          this, SLOT(slotDialogAccepted()));
-  
-  connect(m_cancel_button, SIGNAL(clicked()), 
-          this, SLOT(reject()));
+  //
+  // Connections
+  // 
+  connect(m_tree_widget, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(slotItemClicked(QTreeWidgetItem*,int)));
+  connect(m_tree_widget, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotContextMenuRequested(QPoint)));
+  connect(m_label_edit, SIGNAL(editingFinished()), this, SLOT(slotLabelEdited()));
+  connect(m_ip_edit, SIGNAL(editingFinished()), this, SLOT(slotIPEdited()));
+  connect(m_login_edit, SIGNAL(editingFinished()), this, SLOT(slotLoginEdited()));
+  connect(m_group_combo->lineEdit(), SIGNAL(editingFinished()), this, SLOT(slotGroupEdited()));
+  connect(m_add_group, SIGNAL(triggered(bool)), this, SLOT(slotAddGroupTriggered(bool)));
+  connect(m_delete, SIGNAL(triggered(bool)), this, SLOT(slotDeleteTriggered(bool)));
+  connect(m_clear, SIGNAL(triggered(bool)), this, SLOT(slotClearTriggered(bool)));
+  connect(m_ok_button, SIGNAL(clicked()), this, SLOT(slotDialogAccepted()));
+  connect(m_cancel_button, SIGNAL(clicked()), this, SLOT(slotDialogRejected()));
 }
 
 
@@ -541,7 +551,7 @@ void Smb4KBookmarkEditor::loadBookmarks()
   m_group_combo->clear();
     
   // 
-  // Copy the groups into the internal lists
+  // Copy the groups into the internal list
   // 
   m_groups.clear();
   
@@ -551,13 +561,11 @@ void Smb4KBookmarkEditor::loadBookmarks()
     {
       m_groups << bookmark->groupName();
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
-  // Insert the groups into the tree widget.
+  //
+  // Insert the groups into the tree widget
+  // 
   for (const QString &group : m_groups)
   {
     if (!group.isEmpty())
@@ -569,20 +577,18 @@ void Smb4KBookmarkEditor::loadBookmarks()
       groupItem->setFlags(Qt::ItemIsSelectable|Qt::ItemIsUserCheckable|Qt::ItemIsEnabled|Qt::ItemIsDropEnabled);
       m_tree_widget->addTopLevelItem(groupItem);
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
-  // Insert the bookmarks info the tree widget.
+  // 
+  // Insert the bookmarks info the tree widget
+  // 
   for (const BookmarkPtr &bookmark : m_bookmarks)
   {
     QTreeWidgetItem *bookmarkItem = new QTreeWidgetItem(QTreeWidgetItem::UserType);
     bookmarkItem->setData(0, QTreeWidgetItem::UserType, static_cast<QUrl>(bookmark->url()));
     bookmarkItem->setIcon(0, bookmark->icon());
-    bookmarkItem->setText(0, bookmark->unc());
-    bookmarkItem->setText((m_tree_widget->columnCount() - 1), QString("01_%1").arg(bookmark->unc()));
+    bookmarkItem->setText(0, bookmark->displayString());
+    bookmarkItem->setText((m_tree_widget->columnCount() - 1), QString("01_%1").arg(bookmark->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort)));
     bookmarkItem->setFlags(Qt::ItemIsSelectable|Qt::ItemIsUserCheckable|Qt::ItemIsEnabled|Qt::ItemIsDragEnabled);
     
     if (!bookmark->groupName().isEmpty())
@@ -594,10 +600,6 @@ void Smb4KBookmarkEditor::loadBookmarks()
         items.first()->addChild(bookmarkItem);
         items.first()->setExpanded(true);
       }
-      else
-      {
-        // Do nothing
-      }
     }
     else
     {
@@ -605,7 +607,9 @@ void Smb4KBookmarkEditor::loadBookmarks()
     }
   }
 
+  // 
   // Sort
+  // 
   for (int i = 0; i < m_tree_widget->topLevelItemCount(); ++i)
   {
     m_tree_widget->topLevelItem(i)->sortChildren((m_tree_widget->columnCount() - 1), Qt::AscendingOrder);
@@ -613,22 +617,27 @@ void Smb4KBookmarkEditor::loadBookmarks()
   
   m_tree_widget->sortItems((m_tree_widget->columnCount() - 1), Qt::AscendingOrder);
   
+  //
   // Check that an empty group entry is also present. If it is not there,
   // add it now and insert the groups to the group combo box afterwards.
+  // 
   if (!m_groups.contains("") && !m_groups.contains(QString()))
   {
     m_groups << "";
   }
-  else
-  {
-    // Do nothing
-  }
   
   m_group_combo->addItems(m_groups);
   m_group_combo->setCurrentItem("");
 }
 
 
+QList<BookmarkPtr> Smb4KBookmarkEditor::editedBookmarks()
+{
+  return m_bookmarks;
+}
+
+
+
 BookmarkPtr Smb4KBookmarkEditor::findBookmark(const QUrl &url)
 {
   BookmarkPtr bookmark;
@@ -667,7 +676,7 @@ void Smb4KBookmarkEditor::slotItemClicked(QTreeWidgetItem *item, int /*col*/)
         {
           m_label_edit->setText(bookmark->label());
           m_login_edit->setText(bookmark->login());
-          m_ip_edit->setText(bookmark->hostIP());
+          m_ip_edit->setText(bookmark->hostIpAddress());
           m_group_combo->setCurrentItem(bookmark->groupName());
           m_editors->setEnabled(true);
         }
@@ -698,7 +707,7 @@ void Smb4KBookmarkEditor::slotItemClicked(QTreeWidgetItem *item, int /*col*/)
       {
         m_label_edit->setText(bookmark->label());
         m_login_edit->setText(bookmark->login());
-        m_ip_edit->setText(bookmark->hostIP());
+        m_ip_edit->setText(bookmark->hostIpAddress());
         m_group_combo->setCurrentItem(bookmark->groupName());
         m_editors->setEnabled(true);
       }
@@ -742,10 +751,6 @@ void Smb4KBookmarkEditor::slotLabelEdited()
   {
     bookmark->setLabel(m_label_edit->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 
   // Add label to completion object
   KCompletion *completion = m_label_edit->completionObject();
@@ -754,10 +759,6 @@ void Smb4KBookmarkEditor::slotLabelEdited()
   {
     completion->addItem(m_label_edit->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -772,10 +773,6 @@ void Smb4KBookmarkEditor::slotLoginEdited()
   {
     bookmark->setLogin(m_login_edit->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 
   // Add login to completion object
   KCompletion *completion = m_login_edit->completionObject();
@@ -784,10 +781,6 @@ void Smb4KBookmarkEditor::slotLoginEdited()
   {
     completion->addItem(m_login_edit->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -800,11 +793,7 @@ void Smb4KBookmarkEditor::slotIPEdited()
 
   if (bookmark)
   {
-    bookmark->setHostIP(m_ip_edit->userText());
-  }
-  else
-  {
-    // Do nothing
+    bookmark->setHostIpAddress(m_ip_edit->userText());
   }
 
   // Add login to completion object
@@ -814,10 +803,6 @@ void Smb4KBookmarkEditor::slotIPEdited()
   {
     completion->addItem(m_ip_edit->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -835,10 +820,6 @@ void Smb4KBookmarkEditor::slotGroupEdited()
   {
     return;
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // Set the group name to the bookmark
@@ -849,10 +830,6 @@ void Smb4KBookmarkEditor::slotGroupEdited()
   {
     bookmark->setGroupName(m_group_combo->currentText());
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // Reload the bookmarks (The current item is cleared by this!)
@@ -872,10 +849,6 @@ void Smb4KBookmarkEditor::slotGroupEdited()
       slotItemClicked(*it, 0);
       break;
     }
-    else
-    {
-      // Do nothing
-    }
     
     ++it;
   }
@@ -889,10 +862,6 @@ void Smb4KBookmarkEditor::slotGroupEdited()
   {
     completion->addItem(m_group_combo->currentText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -917,10 +886,6 @@ void Smb4KBookmarkEditor::slotAddGroupTriggered(bool /*checked*/)
     m_group_combo->addItem(group_name);
     m_group_combo->completionObject()->addItem(group_name);
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -947,21 +912,10 @@ void Smb4KBookmarkEditor::slotDeleteTriggered(bool /*checked*/)
         it.remove();
         break;
       }
-      else
-      {
-        // Do nothing
-      }
     }
     
     delete item;
   }
-  
-  //
-  // Reload the bookmarks into the tree widget (We do not
-  // need to reset the current item, because it has just been
-  // removed.
-  //
-  loadBookmarks();
 }
 
 
@@ -975,6 +929,9 @@ void Smb4KBookmarkEditor::slotClearTriggered(bool /*checked*/)
 
 void Smb4KBookmarkEditor::slotDialogAccepted()
 {
+  //
+  // Write the dialog properties to the config file
+  // 
   KConfigGroup group(Smb4KSettings::self()->config(), "BookmarkEditor");
   KWindowConfig::saveWindowSize(windowHandle(), group);
   group.writeEntry("LabelCompletion", m_label_edit->completionObject()->items());
@@ -982,10 +939,23 @@ void Smb4KBookmarkEditor::slotDialogAccepted()
   group.writeEntry("IPCompletion", m_ip_edit->completionObject()->items());
   group.writeEntry("GroupCompletion", m_group_combo->completionObject()->items());
   
+  //
+  // Accept the dialog
+  // 
   accept();
 }
 
 
+void Smb4KBookmarkEditor::slotDialogRejected()
+{
+  //
+  // Reject the dialog
+  // 
+  reject();
+}
+
+
+
 void Smb4KBookmarkEditor::slotIconSizeChanged(int group)
 {
   switch (group)
@@ -1018,10 +988,6 @@ void Smb4KBookmarkEditor::slotAdjust()
         {
           delete *it;
         }
-        else
-        {
-          // Do nothing
-        }
       }
       else
       {
@@ -1031,10 +997,6 @@ void Smb4KBookmarkEditor::slotAdjust()
         {
           bookmark->setGroupName("");
         }
-        else
-        {
-          // Do nothing
-        }        
       }
     }
     else
@@ -1045,12 +1007,9 @@ void Smb4KBookmarkEditor::slotAdjust()
       {
         bookmark->setGroupName((*it)->parent()->text(0));
       }
-      else
-      {
-        // Do nothing
-      }
     }
     ++it;
   }
 }
 
+
