@@ -2,7 +2,7 @@
     This is the global namespace for Smb4K.
                              -------------------
     begin                : Sa Apr 2 2005
-    copyright            : (C) 2005-2017 by Alexander Reinholdt
+    copyright            : (C) 2005-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -31,12 +31,9 @@
 #include "smb4kglobal.h"
 #include "smb4kglobal_p.h"
 #include "smb4knotification.h"
-#include "smb4kscanner.h"
-#include "smb4kmounter.h"
-#include "smb4kprint.h"
 #include "smb4ksynchronizer.h"
-#include "smb4kpreviewer.h"
-#include "smb4ksearch.h"
+#include "smb4kclient.h"
+#include "smb4kmounter.h"
 
 // Qt includes
 #include <QMutex>
@@ -52,75 +49,42 @@ Q_GLOBAL_STATIC(Smb4KGlobalPrivate, p);
 QMutex mutex(QMutex::Recursive /* needed to avoid dead-locks */);
 
 
-const QEvent::Type Smb4KGlobal::Smb4KEvent::LoadSettings =          (QEvent::Type)QEvent::registerEventType();
-const QEvent::Type Smb4KGlobal::Smb4KEvent::SetFocus =              (QEvent::Type)QEvent::registerEventType();
-const QEvent::Type Smb4KGlobal::Smb4KEvent::ScanNetwork =           (QEvent::Type)QEvent::registerEventType();
-const QEvent::Type Smb4KGlobal::Smb4KEvent::AddBookmark =           (QEvent::Type)QEvent::registerEventType();
-const QEvent::Type Smb4KGlobal::Smb4KEvent::MountOrUnmountShare =   (QEvent::Type)QEvent::registerEventType();
-const QEvent::Type Smb4KGlobal::Smb4KEvent::EnableBookmarkAction =  (QEvent::Type)QEvent::registerEventType();
-const QEvent::Type Smb4KGlobal::Smb4KEvent::DisableBookmarkAction = (QEvent::Type)QEvent::registerEventType();
-
-
-Smb4KGlobal::Smb4KEvent::Smb4KEvent(QEvent::Type type): QEvent(type)
-{
-}
-
-
-Smb4KGlobal::Smb4KEvent::~Smb4KEvent()
-{
-}
-
-
-
 void Smb4KGlobal::initCore(bool modifyCursor, bool initClasses)
 {
-  // Should the core use a busy cursor?
-  p->modifyCursor = modifyCursor;
-  
-  // Set default values for some settings.
-  p->setDefaultSettings();
-  
-  // Initialize the necessary core classes
-  if (initClasses)
+  if (!p->coreInitialized)
   {
-    Smb4KScanner::self()->start();
-    Smb4KMounter::self()->start();
-  }
-  else
-  {
-    // Do nothing
-  }
+    // 
+    // Busy cursor
+    // 
+    p->modifyCursor = modifyCursor;
+    
+    // 
+    // Initialize the necessary core classes
+    // 
+    if (initClasses)
+    {
+      Smb4KClient::self()->start();
+      Smb4KMounter::self()->start();
+    }
 
-  p->makeConnections();
-  p->coreInitialized = true;
+    p->coreInitialized = true;
+  }
 }
 
 
 void Smb4KGlobal::abortCore()
 {
-  Smb4KScanner::self()->abortAll();
-  Smb4KMounter::self()->abortAll();
-  Smb4KPrint::self()->abortAll();
-  Smb4KSynchronizer::self()->abortAll();
-  Smb4KPreviewer::self()->abortAll();
-  Smb4KSearch::self()->abortAll();
+  Smb4KClient::self()->abort();
+  Smb4KMounter::self()->abort();
+  Smb4KSynchronizer::self()->abort();
 }
 
 
 bool Smb4KGlobal::coreIsRunning()
 {
-  return (Smb4KScanner::self()->isRunning() ||
+  return (Smb4KClient::self()->isRunning() ||
           Smb4KMounter::self()->isRunning() ||
-          Smb4KPrint::self()->isRunning() ||
-          Smb4KSynchronizer::self()->isRunning() ||
-          Smb4KPreviewer::self()->isRunning() ||
-          Smb4KSearch::self()->isRunning());
-}
-
-
-void Smb4KGlobal::setDefaultSettings()
-{
-  p->setDefaultSettings();
+          Smb4KSynchronizer::self()->isRunning());
 }
 
 
@@ -149,10 +113,6 @@ WorkgroupPtr Smb4KGlobal::findWorkgroup(const QString &name)
       workgroup = w;
       break;
     }
-    else
-    {
-      // Do nothing
-    }
   }
 
   mutex.unlock();
@@ -176,17 +136,9 @@ bool Smb4KGlobal::addWorkgroup(WorkgroupPtr workgroup)
       p->workgroupsList.append(workgroup);
       added = true;
     }
-    else
-    {
-      // Do nothing
-    }
 
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
 
   return added;
 }
@@ -209,17 +161,9 @@ bool Smb4KGlobal::updateWorkgroup(WorkgroupPtr workgroup)
       existingWorkgroup->update(workgroup.data());
       updated = true;
     }
-    else
-    {
-      // Do nothing
-    }
     
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
   
   return updated;
 }
@@ -258,14 +202,6 @@ bool Smb4KGlobal::removeWorkgroup(WorkgroupPtr workgroup)
           p->workgroupsList.takeAt(index).clear();
           removed = true;
         }
-        else
-        {
-          // Do nothing
-        }
-      }
-      else
-      {
-        // Do nothing
       }
 
       workgroup.clear();
@@ -273,10 +209,6 @@ bool Smb4KGlobal::removeWorkgroup(WorkgroupPtr workgroup)
 
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
 
   return removed;
 }
@@ -315,10 +247,6 @@ HostPtr Smb4KGlobal::findHost(const QString &name, const QString &workgroup)
       host = h;
       break;
     }
-    else
-    {
-      // Do nothing
-    }
   }
 
   mutex.unlock();
@@ -342,17 +270,9 @@ bool Smb4KGlobal::addHost(HostPtr host)
       p->hostsList.append(host);
       added = true;
     }
-    else
-    {
-      // Do nothing
-    }
 
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
 
   return added;
 }
@@ -375,17 +295,9 @@ bool Smb4KGlobal::updateHost(HostPtr host)
       existingHost->update(host.data());
       updated = true;
     }
-    else
-    {
-      // Do nothing
-    }
-    
+
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
   
   return updated;
 }
@@ -424,14 +336,6 @@ bool Smb4KGlobal::removeHost(HostPtr host)
           p->hostsList.takeAt(index).clear();
           removed = true;
         }
-        else
-        {
-          // Do nothing
-        }
-      }
-      else
-      {
-        // Do nothing
       }
 
       host.clear();
@@ -439,10 +343,6 @@ bool Smb4KGlobal::removeHost(HostPtr host)
 
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
 
   return removed;
 }
@@ -471,11 +371,7 @@ QList<HostPtr> Smb4KGlobal::workgroupMembers(WorkgroupPtr workgroup)
   {
     if (QString::compare(h->workgroupName(), workgroup->workgroupName(), Qt::CaseInsensitive) == 0)
     {
-      hosts += h;
-    }
-    else
-    {
-      // Do nothing
+      hosts << h;
     }
   }
 
@@ -491,7 +387,7 @@ const QList<SharePtr> &Smb4KGlobal::sharesList()
 }
 
 
-SharePtr Smb4KGlobal::findShare(const QString& unc, const QString& workgroup)
+SharePtr Smb4KGlobal::findShare(const QUrl& url, const QString& workgroup)
 {
   SharePtr share;
   
@@ -499,16 +395,13 @@ SharePtr Smb4KGlobal::findShare(const QString& unc, const QString& workgroup)
 
   for (const SharePtr &s : p->sharesList)
   {
-    if (QString::compare(s->unc(), unc, Qt::CaseInsensitive) == 0 &&
+    if (QString::compare(s->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
+                         url.toString(QUrl::RemoveUserInfo|QUrl::RemovePort), Qt::CaseInsensitive) == 0 &&
         (workgroup.isEmpty() || QString::compare(s->workgroupName(), workgroup, Qt::CaseInsensitive) == 0))
     {
       share = s;
       break;
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   mutex.unlock();
@@ -531,13 +424,13 @@ bool Smb4KGlobal::addShare(SharePtr share)
     //
     // Add the share
     //
-    if (!findShare(share->unc(), share->workgroupName()))
+    if (!findShare(share->url(), share->workgroupName()))
     {
       // 
       // Set the share mounted
       // Only honor shares that are owned by the user
       // 
-      QList<SharePtr> mountedShares = findShareByUNC(share->unc());
+      QList<SharePtr> mountedShares = findShareByUrl(share->url());
       
       if (!mountedShares.isEmpty())
       {
@@ -554,10 +447,6 @@ bool Smb4KGlobal::addShare(SharePtr share)
           }
         }
       }
-      else
-      {
-        // Do nothing
-      }  
       
       // 
       // Add it
@@ -565,14 +454,6 @@ bool Smb4KGlobal::addShare(SharePtr share)
       p->sharesList.append(share);
       added = true;
     }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else
-  {
-    // Do nothing
   }
 
   mutex.unlock();
@@ -594,7 +475,7 @@ bool Smb4KGlobal::updateShare(SharePtr share)
     //
     // Updated the share
     //
-    SharePtr existingShare = findShare(share->unc(), share->workgroupName());
+    SharePtr existingShare = findShare(share->url(), share->workgroupName());
     
     if (existingShare)
     {
@@ -602,7 +483,7 @@ bool Smb4KGlobal::updateShare(SharePtr share)
       // Set the share mounted
       // Only honor shares that are owned by the user
       // 
-      QList<SharePtr> mountedShares = findShareByUNC(share->unc());
+      QList<SharePtr> mountedShares = findShareByUrl(share->url());
       
       if (!mountedShares.isEmpty())
       {
@@ -619,10 +500,6 @@ bool Smb4KGlobal::updateShare(SharePtr share)
           }
         }
       }
-      else
-      {
-        // Do nothing
-      }
       
       // 
       // Update it
@@ -630,17 +507,9 @@ bool Smb4KGlobal::updateShare(SharePtr share)
       existingShare->update(share.data());
       updated = true;
     }
-    else
-    {
-      // Do nothing
-    }
-    
+
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
   
   return updated;
 }
@@ -668,7 +537,7 @@ bool Smb4KGlobal::removeShare(SharePtr share)
     else
     {
       // Try harder to find the share.
-      SharePtr s = findShare(share->unc(), share->workgroupName());
+      SharePtr s = findShare(share->url(), share->workgroupName());
 
       if (s)
       {
@@ -679,14 +548,6 @@ bool Smb4KGlobal::removeShare(SharePtr share)
           p->sharesList.takeAt(index).clear();
           removed = true;
         }
-        else
-        {
-          // Do nothing
-        }
-      }
-      else
-      {
-        // Do nothing
       }
 
       share.clear();
@@ -694,10 +555,6 @@ bool Smb4KGlobal::removeShare(SharePtr share)
 
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
 
   return removed;
 }
@@ -729,10 +586,6 @@ QList<SharePtr> Smb4KGlobal::sharedResources(HostPtr host)
     {
       shares += s;
     }
-    else
-    {
-      // Do nothing
-    }
   }
 
   mutex.unlock();
@@ -763,16 +616,8 @@ SharePtr Smb4KGlobal::findShareByPath(const QString &path)
         share = s;
         break;
       }
-      else
-      {
-        // Do nothing
-      }
     }
   }
-  else
-  {
-    // Do nothing
-  }
 
   mutex.unlock();
 
@@ -780,30 +625,24 @@ SharePtr Smb4KGlobal::findShareByPath(const QString &path)
 }
 
 
-QList<SharePtr> Smb4KGlobal::findShareByUNC(const QString &unc)
+QList<SharePtr> Smb4KGlobal::findShareByUrl(const QUrl &url)
 {
   QList<SharePtr> shares;
 
   mutex.lock();
 
-  if (!unc.isEmpty() && !p->mountedSharesList.isEmpty())
+  if (!url.isEmpty() && url.isValid() && !p->mountedSharesList.isEmpty())
   {
     for (const SharePtr &s : p->mountedSharesList)
     {
-      if (QString::compare(s->unc(), unc, Qt::CaseInsensitive) == 0)
+      if (QString::compare(s->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
+                           url.toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
+                           Qt::CaseInsensitive) == 0)
       {
-        shares += s;
-      }
-      else
-      {
-        // Do nothing
+        shares << s;
       }
     }
   }
-  else
-  {
-    // Do nothing
-  }
 
   mutex.unlock();
 
@@ -823,10 +662,6 @@ QList<SharePtr> Smb4KGlobal::findInaccessibleShares()
     {
       inaccessibleShares += s;
     }
-    else
-    {
-      // Do nothing
-    }
   }
 
   mutex.unlock();
@@ -846,25 +681,18 @@ bool Smb4KGlobal::addMountedShare(SharePtr share)
     mutex.lock();
 
     //
-    // Copy the mount data to the network share (needed for unmounting from the network browser)
+    // Copy the mount data to the network share if available.
     // Only honor shares that were mounted by the user.
     //
     if (!share->isForeign())
     {
-      SharePtr networkShare = findShare(share->unc(), share->workgroupName());
+      // Network share
+      SharePtr networkShare = findShare(share->url(), share->workgroupName());
       
       if (networkShare)
       {
         networkShare->setMountData(share.data());
       }
-      else
-      {
-        // Do nothing
-      }
-    }
-    else
-    {
-      // Do nothing
     }
 
     if (!findShareByPath(share->path()))
@@ -877,13 +705,9 @@ bool Smb4KGlobal::addMountedShare(SharePtr share)
       if (networkHost)
       {
         // Set the IP address
-        if (!share->hasHostIP() || networkHost->ip() != share->hostIP())
+        if (!share->hasHostIpAddress() || networkHost->ipAddress() != share->hostIpAddress())
         {
-          share->setHostIP(networkHost->ip());
-        }
-        else
-        {
-          // Do nothing
+          share->setHostIpAddress(networkHost->ipAddress());
         }
         
         // Set the workgroup name
@@ -891,14 +715,6 @@ bool Smb4KGlobal::addMountedShare(SharePtr share)
         {
           share->setWorkgroupName(networkHost->workgroupName());
         }
-        else
-        {
-          // Do nothing
-        }          
-      }
-      else
-      {
-        // Do nothing
       }
       
       p->mountedSharesList.append(share);
@@ -913,23 +729,11 @@ bool Smb4KGlobal::addMountedShare(SharePtr share)
           p->onlyForeignShares = false;
           break;
         }
-        else
-        {
-          // Do nothing
-        }
       }
     }
-    else
-    {
-      // Do nothing
-    }
 
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
 
   return added;
 }
@@ -951,20 +755,12 @@ bool Smb4KGlobal::updateMountedShare(SharePtr share)
     //
     if (!share->isForeign())
     {
-      SharePtr networkShare = findShare(share->unc(), share->workgroupName());
+      SharePtr networkShare = findShare(share->url(), share->workgroupName());
       
       if (networkShare)
       {
         networkShare->setMountData(share.data());
       }
-      else
-      {
-        // Do nothing
-      }
-    }
-    else
-    {
-      // Do nothing
     }
     
     SharePtr mountedShare = findShareByPath(share->path());
@@ -979,13 +775,9 @@ bool Smb4KGlobal::updateMountedShare(SharePtr share)
       if (networkHost)
       {
         // Set the IP address
-        if (!share->hasHostIP() || networkHost->ip() != share->hostIP())
+        if (!share->hasHostIpAddress() || networkHost->ipAddress() != share->hostIpAddress())
         {
-          share->setHostIP(networkHost->ip());
-        }
-        else
-        {
-          // Do nothing
+          share->setHostIpAddress(networkHost->ipAddress());
         }
         
         // Set the workgroup name
@@ -993,16 +785,7 @@ bool Smb4KGlobal::updateMountedShare(SharePtr share)
         {
           share->setWorkgroupName(networkHost->workgroupName());
         }
-        else
-        {
-          // Do nothing
-        }          
       }
-      else
-      {
-        // Do nothing
-      }
-      
       
       //
       // Update share
@@ -1010,17 +793,9 @@ bool Smb4KGlobal::updateMountedShare(SharePtr share)
       mountedShare->setMountData(share.data());
       updated = true;
     }
-    else
-    {
-      // Do nothing
-    }
     
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
   
   return updated;
 }
@@ -1036,17 +811,24 @@ bool Smb4KGlobal::removeMountedShare(SharePtr share)
   {
     mutex.lock();
     
-    SharePtr networkShare = findShare(share->unc(), share->workgroupName());
-    
-    if (networkShare)
+    //
+    // Reset the mount data for the network share and the
+    // search result
+    // 
+    if (!share->isForeign())
     {
-      networkShare->resetMountData();
-    }
-    else
-    {
-      // Do nothing
+      // Network share
+      SharePtr networkShare = findShare(share->url(), share->workgroupName());
+      
+      if (networkShare)
+      {
+        networkShare->resetMountData();
+      }
     }
 
+    //
+    // Remove the mounted share
+    // 
     int index = p->mountedSharesList.indexOf(share);
 
     if (index != -1)
@@ -1069,14 +851,6 @@ bool Smb4KGlobal::removeMountedShare(SharePtr share)
           p->mountedSharesList.takeAt(index).clear();
           removed = true;
         }
-        else
-        {
-          // Do nothing
-        }
-      }
-      else
-      {
-        // Do nothing
       }
 
       share.clear();
@@ -1089,18 +863,10 @@ bool Smb4KGlobal::removeMountedShare(SharePtr share)
         p->onlyForeignShares = false;
         break;
       }
-      else
-      {
-        // Do nothing
-      }
     }
     
     mutex.unlock();
   }
-  else
-  {
-    // Do nothing
-  }
   
   return removed;
 }
@@ -1152,36 +918,9 @@ void Smb4KGlobal::openShare(SharePtr share, OpenWith openWith)
 }
 
 
-const QMap<QString,QString> &Smb4KGlobal::globalSambaOptions(bool read)
+const QMap<QString,QString> &Smb4KGlobal::globalSambaOptions()
 {
-  return p->globalSambaOptions(read);
-}
-
-
-const QString Smb4KGlobal::winsServer()
-{
-  QMap<QString,QString> global_opts = p->globalSambaOptions(false);
-  QString wins_server;
-  
-  if (global_opts.contains("wins server"))
-  {
-    wins_server = global_opts.value("wins server");
-  }
-  else
-  {
-    if (global_opts.contains("wins support") &&
-         (QString::compare(global_opts.value("wins support"), "yes", Qt::CaseInsensitive) == 0 ||
-          QString::compare(global_opts.value("wins support"), "true", Qt::CaseInsensitive) == 0))
-    {
-      wins_server = "127.0.0.1";
-    }
-    else
-    {
-      // Do nothing
-    }
-  }
-  
-  return wins_server;
+  return p->globalSambaOptions();
 }
 
 
