@@ -32,16 +32,22 @@
 // Qt includes
 #include <QStringList>
 #include <QNetworkConfigurationManager>
+#include <QNetworkSession>
+#include <QDBusInterface>
+#include <QDBusUnixFileDescriptor>
 
 class Smb4KHardwareInterfacePrivate
 {
   public:
     QNetworkConfigurationManager networkConfigManager;
-    bool networkConfigUpdated;
+    QNetworkSession *networkSession;
     QStringList udis;
 #if defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
     QStringList mountPoints;
 #endif
+    QScopedPointer<QDBusInterface> dbusInterface;
+    QDBusUnixFileDescriptor fileDescriptor;
+    bool systemOnline;
 };
 
 
