@@ -2,7 +2,7 @@
     This class handles the homes shares
                              -------------------
     begin                : Do Aug 10 2006
-    copyright            : (C) 2006-2017 by Alexander Reinholdt
+    copyright            : (C) 2006-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -41,7 +41,7 @@
 #include <QTextCodec>
 #include <QXmlStreamWriter>
 #include <QXmlStreamReader>
-#include <QCoreApplication>
+#include <QApplication>
 #include <QPointer>
 
 // KDE includes
@@ -63,18 +63,14 @@ Smb4KHomesSharesHandler::Smb4KHomesSharesHandler(QObject *parent)
   {
     dir.mkpath(path);
   }
-  else
-  {
-    // Do nothing
-  }
   
   d->homesUsers = readUserNames(false);
   
+  // 
   // Connections
-  connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), 
-          this, SLOT(slotAboutToQuit()));
-  connect(Smb4KProfileManager::self(), SIGNAL(activeProfileChanged(QString)), 
-          this, SLOT(slotActiveProfileChanged(QString)));
+  // 
+  connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), this, SLOT(slotAboutToQuit()));
+  connect(Smb4KProfileManager::self(), SIGNAL(activeProfileChanged(QString)), this, SLOT(slotActiveProfileChanged(QString)));
 }
 
 
@@ -93,18 +89,18 @@ Smb4KHomesSharesHandler *Smb4KHomesSharesHandler::self()
 }
 
 
-bool Smb4KHomesSharesHandler::specifyUser(const SharePtr &share, bool overwrite, QWidget *parent)
+bool Smb4KHomesSharesHandler::specifyUser(const SharePtr &share, bool overwrite)
 {
   Q_ASSERT(share);
   bool success = false;
   
   // Avoid that the dialog is opened although the homes
   // user name has already been defined.
-  if (share->isHomesShare() && (share->homeUNC().isEmpty() || overwrite))
+  if (share->isHomesShare() && (share->homeUrl().isEmpty() || overwrite))
   {
     QStringList users = findHomesUsers(share);
     
-    QPointer<Smb4KHomesUserDialog> dlg = new Smb4KHomesUserDialog(share, parent);
+    QPointer<Smb4KHomesUserDialog> dlg = new Smb4KHomesUserDialog(share, QApplication::activeWindow());
     dlg->setUserNames(users);
     
     if (dlg->exec() == QDialog::Accepted)
@@ -120,26 +116,14 @@ bool Smb4KHomesSharesHandler::specifyUser(const SharePtr &share, bool overwrite,
         {
           share->setPassword(QString());
         }
-        else
-        {
-          // Do nothing
-        }
         
         // Set the login name.
         share->setLogin(login);        
         success = true;
       }
-      else
-      {
-        // Do nothing
-      }
       
       writeUserNames(d->homesUsers);
     }
-    else
-    {
-      // Do nothing
-    }
     
     delete dlg;
   }
@@ -229,18 +213,10 @@ const QList<Smb4KHomesUsers *> Smb4KHomesSharesHandler::readUserNames(bool allUs
                       {
                         u << xmlReader.readElementText();
                       }
-                      else
-                      {
-                        // Do nothing
-                      }
                     }
                     
                     users->setUsers(u);
                   }
-                  else
-                  {
-                    // Do nothing
-                  }
 
                   continue;
                 }
@@ -275,10 +251,6 @@ const QList<Smb4KHomesUsers *> Smb4KHomesSharesHandler::readUserNames(bool allUs
     {
       Smb4KNotification::readingFileFailed(xmlFile, xmlReader.errorString());
     }
-    else
-    {
-      // Do nothing
-    }
   }
   else
   {
@@ -286,10 +258,6 @@ const QList<Smb4KHomesUsers *> Smb4KHomesSharesHandler::readUserNames(bool allUs
     {
       Smb4KNotification::openingFileFailed(xmlFile);
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   return list;
@@ -316,20 +284,12 @@ void Smb4KHomesSharesHandler::writeUserNames(const QList<Smb4KHomesUsers *> &lis
       {
         it.remove();
       }
-      else
-      {
-        // Do nothing
-      }
     }
   }
-  else
-  {
-    // Do nothing
-  }
   
-  for (int i = 0; i < list.size(); ++i)
+  for (Smb4KHomesUsers *users : list)
   {
-    allUsers << new Smb4KHomesUsers(*list[i]);
+    allUsers << new Smb4KHomesUsers(*users);
   }
   
   QFile xmlFile(dataLocation()+QDir::separator()+"homes_shares.xml");
@@ -344,7 +304,7 @@ void Smb4KHomesSharesHandler::writeUserNames(const QList<Smb4KHomesUsers *> &lis
       xmlWriter.writeStartElement("homes_shares");
       xmlWriter.writeAttribute("version", "1.0");
 
-      for (int i = 0; i < allUsers.size(); ++i)
+      for (Smb4KHomesUsers *users : allUsers)
       {
         xmlWriter.writeStartElement("homes");
         
@@ -357,17 +317,17 @@ void Smb4KHomesSharesHandler::writeUserNames(const QList<Smb4KHomesUsers *> &lis
         }
         else
         {
-          xmlWriter.writeAttribute("profile", allUsers.at(i)->profile());
+          xmlWriter.writeAttribute("profile", users->profile());
         }
-        // xmlWriter.writeAttribute("profile", allUsers.at(i)->profile);
-        xmlWriter.writeTextElement("host", allUsers.at(i)->hostName());
-        xmlWriter.writeTextElement("workgroup", allUsers.at(i)->workgroupName());
-        xmlWriter.writeTextElement("ip", allUsers.at(i)->hostIP());
+        // xmlWriter.writeAttribute("profile", users->profile());
+        xmlWriter.writeTextElement("host", users->hostName());
+        xmlWriter.writeTextElement("workgroup", users->workgroupName());
+        xmlWriter.writeTextElement("ip", users->hostIP());
         xmlWriter.writeStartElement("users");
 
-        for (int j = 0; j < allUsers.at(i)->users().size(); ++j)
+        for (const QString &user : users->users())
         {
-          xmlWriter.writeTextElement("user", allUsers.at(i)->users().at(j));
+          xmlWriter.writeTextElement("user", user);
         }
 
         xmlWriter.writeEndElement();
@@ -448,10 +408,6 @@ void Smb4KHomesSharesHandler::addHomesUsers(const SharePtr &share, const QString
       }
     }
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (!found)
   {
@@ -459,10 +415,6 @@ void Smb4KHomesSharesHandler::addHomesUsers(const SharePtr &share, const QString
     u->setProfile(Smb4KProfileManager::self()->activeProfile());
     d->homesUsers << u;
   }
-  else
-  {
-    // Do nothing
-  }  
 }
 
 
@@ -478,10 +430,6 @@ void Smb4KHomesSharesHandler::migrateProfile(const QString& from, const QString&
     {
       allUsers[i]->setProfile(to);
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   // Write the new list to the file.
@@ -512,10 +460,6 @@ void Smb4KHomesSharesHandler::removeProfile(const QString& name)
     {
       it.remove();
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   // Write the new list to the file.
