@@ -2,7 +2,7 @@
     Private helpers for the homes shares handler
                              -------------------
     begin                : Mo Apr 11 2011
-    copyright            : (C) 2011-2017 by Alexander Reinholdt
+    copyright            : (C) 2011-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -42,6 +42,7 @@
 #include <QLineEdit>
 #include <QPushButton>
 #include <QDialogButtonBox>
+#include <QWindow>
 
 // KDE includes
 #define TRANSLATION_DOMAIN "smb4k-core"
@@ -54,7 +55,7 @@ Smb4KHomesUsers::Smb4KHomesUsers(const SharePtr &s, const QStringList &u)
   m_workgroup_name = s->workgroupName();
   m_host_name      = s->hostName();
   m_share_name     = s->shareName();
-  m_host_ip.setAddress(s->hostIP());
+  m_host_ip.setAddress(s->hostIpAddress());
   m_users          = u;
 }
 
@@ -156,14 +157,39 @@ void Smb4KHomesUsers::setProfile(const QString& profile)
 Smb4KHomesUserDialog::Smb4KHomesUserDialog(const SharePtr &share, QWidget *parent) 
 : QDialog(parent), m_share(share)
 {
+  //
+  // Set the window title
+  // 
   setWindowTitle(i18n("Specify User"));
-  
+
+  //
+  // Setup the view
+  // 
   setupView();
   
-  setMinimumWidth(sizeHint().width() > 350 ? sizeHint().width() : 350);
-  
+  //
+  // Set the dialog size
+  // 
+  create();
+
   KConfigGroup group(Smb4KSettings::self()->config(), "HomesUserDialog");
-  KWindowConfig::restoreWindowSize(windowHandle(), group);
+  QSize dialogSize;
+  
+  if (group.exists())
+  {
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    dialogSize = windowHandle()->size();
+  }
+  else
+  {
+    dialogSize = sizeHint();
+  }
+  
+  resize(dialogSize); // workaround for QTBUG-40584
+
+  //
+  // Fill the completion object
+  // 
   m_user_combo->completionObject()->setItems(group.readEntry("HomesUsersCompletion", QStringList()));
 }
 
@@ -189,7 +215,7 @@ void Smb4KHomesUserDialog::setupView()
   pixmap->setPixmap(user_pix);
   pixmap->setAlignment(Qt::AlignBottom);
 
-  QLabel *label = new QLabel(i18n("Please specify a username for share<br><b>%1</b>.", m_share->unc()), description);
+  QLabel *label = new QLabel(i18n("Please specify a username for share<br><b>%1</b>.", m_share->displayString()), description);
   label->setWordWrap(true);
   label->setAlignment(Qt::AlignBottom);
 
@@ -248,10 +274,6 @@ void Smb4KHomesUserDialog::setUserNames(const QStringList &users)
     m_user_combo->setCurrentItem("");
     m_clear_button->setEnabled(true);
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -268,10 +290,6 @@ QStringList Smb4KHomesUserDialog::userNames()
   {
     users << m_user_combo->currentText();
   }
-  else
-  {
-    // Do nothing
-  }
   
   return users;
 }
@@ -308,9 +326,5 @@ void Smb4KHomesUserDialog::slotHomesUserEntered()
   {
     completion->addItem(m_user_combo->currentText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
