@@ -2,7 +2,7 @@
     Smb4K's container class for information about a host.
                              -------------------
     begin                : Sa Jan 26 2008
-    copyright            : (C) 2008-2017 by Alexander Reinholdt
+    copyright            : (C) 2008-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -34,7 +34,7 @@
 // Qt includes
 #include <QStringList>
 #include <QDebug>
-#include <QHostAddress>
+#include <QUrl>
 
 // KDE includes
 #include <KIconThemes/KIconLoader>
@@ -43,7 +43,6 @@
 class Smb4KHostPrivate
 {
   public:
-    QUrl url;
     QString workgroup;
     QHostAddress ip;
     QString comment;
@@ -54,9 +53,9 @@ class Smb4KHostPrivate
 Smb4KHost::Smb4KHost(const QString &name)
 : Smb4KBasicNetworkItem(Host), d(new Smb4KHostPrivate)
 {
-  d->isMaster     = false;
+  d->isMaster = false;
+  *pIcon = KDE::icon("network-server");
   setHostName(name);
-  setIcon(KDE::icon("network-server"));
 }
 
 
@@ -65,13 +64,9 @@ Smb4KHost::Smb4KHost(const Smb4KHost &h)
 {
   *d = *h.d;
   
-  if (icon().isNull())
+  if (pIcon->isNull())
   {
-    setIcon(KDE::icon("network-server"));
-  }
-  else
-  {
-    // Do nothing
+    *pIcon = KDE::icon("network-server");
   }
 }
 
@@ -79,8 +74,8 @@ Smb4KHost::Smb4KHost(const Smb4KHost &h)
 Smb4KHost::Smb4KHost()
 : Smb4KBasicNetworkItem(Host), d(new Smb4KHostPrivate)
 {
-  d->isMaster     = false;
-  setIcon(KDE::icon("network-server"));
+  d->isMaster = false;
+  *pIcon = KDE::icon("network-server");
 }
 
 
@@ -91,83 +86,20 @@ Smb4KHost::~Smb4KHost()
 
 void Smb4KHost::setHostName(const QString &name)
 {
-  d->url.setHost(name);
-  d->url.setScheme("smb");
+  pUrl->setHost(name);
+  pUrl->setScheme("smb");
 }
 
 
 QString Smb4KHost::hostName() const
 {
-  return d->url.host().toUpper();
-}
-
-
-QString Smb4KHost::unc() const
-{
-  QString unc;
-  
-  if (!hostName().isEmpty())
-  {
-    unc = QString("//%1").arg(hostName());
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  return unc;
-}
-
-
-void Smb4KHost::setURL(const QUrl &url)
-{
-  // Check validity.
-  if (!url.isValid())
-  {
-    return;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  // Check protocol
-  if (url.scheme().isEmpty() || QString::compare(url.scheme(), "smb") == 0)
-  {
-    // Do nothing
-  }
-  else
-  {
-    return;
-  }
-
-  // Check that this is a host item
-  if (!url.path().isEmpty())
-  {
-    return;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  // Set the URL
-  d->url = url;
-
-  // Force protocol
-  d->url.setScheme("smb");
-}
-
-
-QUrl Smb4KHost::url() const
-{
-  return d->url;
+  return pUrl->host().toUpper();
 }
 
 
 void Smb4KHost::setWorkgroupName(const QString &workgroup)
 {
-  d->workgroup = workgroup;
+  d->workgroup = workgroup.toUpper();
 }
 
 
@@ -177,19 +109,28 @@ QString Smb4KHost::workgroupName() const
 }
 
 
-void Smb4KHost::setIP(const QString &ip)
+void Smb4KHost::setIpAddress(const QString &ip)
 {
   d->ip.setAddress(ip);
 }
 
 
-QString Smb4KHost::ip() const
+void Smb4KHost::setIpAddress(const QHostAddress& address)
+{
+  if (!address.isNull() && address.protocol() != QAbstractSocket::UnknownNetworkLayerProtocol)
+  {
+    d->ip = address;
+  }
+}
+
+
+QString Smb4KHost::ipAddress() const
 {
   return d->ip.toString();
 }
 
 
-bool Smb4KHost::hasIP() const
+bool Smb4KHost::hasIpAddress() const
 {
   return !d->ip.isNull();
 }
@@ -219,136 +160,46 @@ bool Smb4KHost::isMasterBrowser() const
 }
 
 
-bool Smb4KHost::isEmpty() const
-{
-  if (!d->url.isEmpty())
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if (!d->workgroup.isEmpty())
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if (!d->ip.isNull())
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if (!d->comment.isEmpty())
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  // Do not include icon here.
-
-  return true;
-}
-
-
 void Smb4KHost::setLogin(const QString &login)
 {
-  d->url.setUserName(login);
+  pUrl->setUserName(login);
 }
 
 
 QString Smb4KHost::login() const
 {
-  return d->url.userName();
+  return pUrl->userName();
 }
 
 
 void Smb4KHost::setPassword(const QString &passwd)
 {
-  d->url.setPassword(passwd);
+  pUrl->setPassword(passwd);
 }
 
 
 QString Smb4KHost::password() const
 {
-  return d->url.password();
+  return pUrl->password();
 }
 
 
 void Smb4KHost::setPort(int port)
 {
-  d->url.setPort(port);
+  pUrl->setPort(port);
 }
 
 
 int Smb4KHost::port() const
 {
-  return d->url.port();
-}
-
-
-bool Smb4KHost::equals(Smb4KHost *host) const
-{
-  Q_ASSERT(host);
-
-  if (d->url != host->url())
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if (QString::compare(workgroupName(), host->workgroupName()) != 0)
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if (QString::compare(ip(), host->ip()) != 0)
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if (QString::compare(comment(), host->comment()) != 0)
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  // Do not include icon here.
-
-  return true;
+  return pUrl->port();
 }
 
 
 void Smb4KHost::setAuthInfo(Smb4KAuthInfo *authInfo)
 {
-  d->url.setUserName(authInfo->userName());
-  d->url.setPassword(authInfo->password());
+  pUrl->setUserName(authInfo->userName());
+  pUrl->setPassword(authInfo->password());
 }
 
 
@@ -357,23 +208,15 @@ void Smb4KHost::update(Smb4KHost* host)
   if (QString::compare(workgroupName(), host->workgroupName()) == 0 &&
       QString::compare(hostName(), host->hostName()) == 0)
   {
-    setURL(host->url());
+    *pUrl = host->url();
     setComment(host->comment());
     setIsMasterBrowser(host->isMasterBrowser());
     
     // Do not kill the already discovered IP address
-    if (!hasIP() && host->hasIP())
+    if (!hasIpAddress() && host->hasIpAddress())
     {
-      setIP(host->ip());
+      setIpAddress(host->ipAddress());
     }
-    else
-    {
-      // Do nothing
-    }    
-  }
-  else
-  {
-    // Do nothing
   }
 }
 
