@@ -2,7 +2,7 @@
     Smb4K's container class for information about a share.
                              -------------------
     begin                : Mo Jan 28 2008
-    copyright            : (C) 2008-2017 by Alexander Reinholdt
+    copyright            : (C) 2008-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -34,7 +34,7 @@
 #include <QStringList>
 #include <QtGlobal>
 #include <QScopedPointer>
-#include <QUrl>
+#include <QHostAddress>
 
 // KDE includes
 #include <KCoreAddons/KUser>
@@ -63,14 +63,12 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
     Smb4KShare(const QString &hostName, const QString &shareName);
 
     /**
-     * This constructor takes the UNC @p unc (in the form [smb:]//[USER@]HOST/SHARE) as
-     * only argument. It feeds the internal url object with the string, that extracts
-     * all parts from it. All other information has to be set by the other functions
-     * this class provides.
+     * This constructor takes the URL @p url as only argument. All other 
+     * information has to be set by the other functions this class provides.
      *
-     * @param unc           The UNC in the form [smb:]//[USER@]HOST/SHARE.
+     * @param url           The URL
      */
-    explicit Smb4KShare(const QString &unc);
+    explicit Smb4KShare(const QUrl &url);
 
     /**
      * This is the copy constructor. It takes another Smb4KShare item and copies all
@@ -118,54 +116,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the host name
      */
     QString hostName() const;
-
-    /**
-     * Returns the UNC (Uniform Naming Convention string) in the form //HOST/Share.
-     * 
-     * This function should only be used for basic comparisons or for display
-     * purposes. If you need to do sophisticated comparisons, use the url() 
-     * function instead.
-     * 
-     * Please note that this function returns a modified URL string (uppercase
-     * hostname, etc.) and automatically strips a trailing slash if one is present.
-     *
-     * @returns the UNC.
-     */
-    QString unc() const;
-                                                   
-    /**
-     * In case of a 'homes' share, this function returns the UNC (Uniform 
-     * Naming Convention string) of the user's home repository in the form 
-     * //HOST/User.
-     * 
-     * If the share is not a 'homes' share or no user name for the homes share
-     * has been defined, this function returns an empty string.
-     * 
-     * This function should only be used for basic comparisons or for display
-     * purposes. If you need to do sophisticated comparisons, use the url() 
-     * function instead.
-     * 
-     * Please note that this function returns a modified URL string (uppercase
-     * hostname, etc.) and automatically strips a trailing slash if one is present.
-     *
-     * @returns the UNC.
-     */
-    QString homeUNC() const;
     
-    /**
-     * Sets the URL of the share after some checks are passed.
-     * 
-     * @param url             The URL of the network item
-     */
-    void setURL(const QUrl &url);
-    
-    /**
-     * Returns the URL of the share.
-     * 
-     * @returns the URL of the share.
-     */
-    QUrl url() const;
-                                                       
     /**
      * In case of a 'homes' share, this function returns the URL of the user's 
      * home repository.
@@ -175,28 +126,19 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * 
      * @returns the user's home repository's URL.
      */
-    QUrl homeURL() const;
-
-    /**
-     * Returns the host's UNC (Uniform Naming Convention string) in the form //HOST.
-     * 
-     * This function should only be used for basic comparisons or for display
-     * purposes. If you need to do sophisticated comparisons, use the url() 
-     * function instead.
-     * 
-     * Please note that this function returns a modified URL string (uppercase
-     * hostname) and automatically strips a trailing slash if one is present.
-     *
-     * @returns the UNC of the host.
-     */
-    QString hostUNC() const;
+    QUrl homeUrl() const;
     
     /**
      * Returns the display string. Prefer this over all other alternatives in your
      * GUI.
+     * 
+     * @param showHomesShare  Show the name of the users home share instead of 'homes'
+     *                        in case this is a homes share. Setting this argument on a 
+     *                        non-homes share does nothing.
+     * 
      * @returns the display string.
      */
-    QString displayString() const;
+    QString displayString(bool showHomeShare = false) const;
 
     /**
      * Set the workgroup where the host is located that offers this share.
@@ -212,22 +154,22 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the workgroup name
      */
     QString workgroupName() const;
-
+    
     /**
-     * Sets the type string (Disk, Print, IPC) of the share.
-     *
-     * @param type          The string defining the type of the share
+     * Set the type of the share as reported by the server.
+     * 
+     * @param type          The type of the string
      */
-    void setTypeString(const QString &typeString);
+    void setShareType(Smb4KGlobal::ShareType type);
 
     /**
-     * Returns the type string of the share as reported by the server. If you are
-     * looking for a translated type string, then use the translatedTypeString()
+     * Returns the type of the share as reported by the server. If you are
+     * looking for a translated type string, then use the shareTypeString()
      * function.
      *
      * @returns the type of the share.
      */
-    QString typeString() const;
+    Smb4KGlobal::ShareType shareType() const;
 
     /**
      * Returns the translated type string of the share. You can use this
@@ -235,7 +177,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      *
      * @returns a translated type string.
      */
-    QString translatedTypeString() const;
+    QString shareTypeString() const;
 
     /**
      * Sets the comment that was defined for the share.
@@ -257,7 +199,15 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      *
      * @param ip              The host's IP address
      */
-    void setHostIP(const QString &ip);
+    void setHostIpAddress(const QString &ip);
+    
+    /**
+     * Set the IP address of the host where the share is located. @p ip will only be accepted
+     * if it is compatible with either IPv4 or IPv6.
+     *
+     * @param ip              The host's IP address
+     */
+    void setHostIpAddress(const QHostAddress &address);
 
     /**
      * Returns the IP address of the host. If the IP address was not compatible
@@ -266,14 +216,14 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      *
      * @returns the IP address of the host or an empty string.
      */
-    QString hostIP() const;
+    QString hostIpAddress() const;
     
     /**
      * Returns TRUE if the host's IP address is set and FALSE otherwise.
      * 
      * @returns TRUE if the host's IP address is set and FALSE otherwise.
      */
-    bool hasHostIP() const;
+    bool hasHostIpAddress() const;
 
     /**
      * If the share is a hidden one, i.e. it ends with a '$', this function returns
@@ -475,59 +425,6 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      */
     QString diskUsageString() const;
 
-    /**
-     * Enumeration for the checks.
-     *
-     * @enum Full               Full comparison
-     * @enum NetworkOnly        Only the network related values are compared
-     * @enum MinimalNetworkOnly Only the absolutely necessary network related values
-     *                          are compared
-     * @enum LocalOnly          Only those values are compared that are of local 
-     *                          importance
-     * @enum MinimalLocalOnly   Only those values are compared that have local importance
-     *                          and are absolutely necessary for a comparison
-     */
-    enum CheckFlags{ Full,
-                     NetworkOnly,
-                     MinimalNetworkOnly,
-                     LocalOnly,
-                     MinimalLocalOnly };
-
-    /**
-     * Compare another Smb4KShare object with this one an return TRUE if both carry
-     * the same data. Depending on the value of @p flag either all data will be compared
-     * or only the one that is network related or the one that is of local importance.
-     *
-     * Please note, that the UNC won't be checked with the flag CheckFlags::NetworkOnly,
-     * but only with either CheckFlags::Full or CheckFlags::LocalOnly.
-     *
-     * @param share           The Smb4KShare object that should be compared with this
-     *                        one.
-     *
-     * @param flag            The flag that determines which values are compared.
-     *
-     * @returns TRUE if the data that was compared is the same.
-     */
-    bool equals(Smb4KShare *share, CheckFlags flag) const;
-                 
-    /**
-     * Operator to check if two shares are equal. This operator performs a full check.
-     */
-    bool operator==(Smb4KShare share) const { return equals(&share, Full); }
-
-    /**
-     * Returns TRUE if values that were checked according to @p flag are empty.
-     * Modified booleans are not considered.
-     *
-     * Please note, that the UNC won't be checked with the flag CheckFlags::NetworkOnly,
-     * but only with either CheckFlags::Full or CheckFlags::LocalOnly.
-     *
-     * @param flag            The flag that determines which values are checked.
-     *
-     * @returns TRUE if the item is empty.
-     */
-    bool isEmpty(CheckFlags flag = Full) const;
-
     /**
      * If this share was mounted, set @p mounted to TRUE. This function will not
      * work with printer shares.
@@ -627,12 +524,12 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
     void update(Smb4KShare *share);
     
   private:
+    const QScopedPointer<Smb4KSharePrivate> d;
+    
     /**
      * Set up the shares icon.
      */
     void setShareIcon();
-
-    const QScopedPointer<Smb4KSharePrivate> d;
 };
 
 #endif
