@@ -3,7 +3,7 @@
     class.
                              -------------------
     begin                : Fr Okt 24 2008
-    copyright            : (C) 2008-2017 by Alexander Reinholdt
+    copyright            : (C) 2008-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -42,6 +42,8 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QDialogButtonBox>
+#include <QWindow>
+#include <QApplication>
 
 // KDE includes
 #define TRANSLATION_DOMAIN "smb4k-core"
@@ -54,8 +56,8 @@
 using namespace Smb4KGlobal;
 
 
-Smb4KSyncJob::Smb4KSyncJob(QObject *parent) : KJob(parent),
-  m_started(false), m_share(0), m_parent_widget(0), m_process(0)
+Smb4KSyncJob::Smb4KSyncJob(QObject *parent) 
+: KJob(parent), m_share(0), m_process(0)
 {
   setCapabilities(KJob::Killable);
   m_job_tracker = new KUiServerJobTracker(this);
@@ -69,16 +71,16 @@ Smb4KSyncJob::~Smb4KSyncJob()
 
 void Smb4KSyncJob::start()
 {
-  m_started = true;
   QTimer::singleShot(0, this, SLOT(slotStartSynchronization()));
 }
 
 
-void Smb4KSyncJob::setupSynchronization(const SharePtr &share, QWidget *parent)
+void Smb4KSyncJob::setupSynchronization(const SharePtr &share)
 {
-  Q_ASSERT(share);
-  m_share = share;
-  m_parent_widget = parent;
+  if (share)
+  {
+    m_share = share;
+  }
 }
 
 
@@ -86,11 +88,7 @@ bool Smb4KSyncJob::doKill()
 {
   if (m_process && m_process->state() != KProcess::NotRunning)
   {
-    m_process->abort();
-  }
-  else
-  {
-    // Do nothing
+    m_process->terminate();
   }
   
   return KJob::doKill();
@@ -121,29 +119,21 @@ void Smb4KSyncJob::slotStartSynchronization()
   if (m_share)
   {
     // Show the user an URL input dialog.
-    QPointer<Smb4KSynchronizationDialog> dlg = new Smb4KSynchronizationDialog(m_share, m_parent_widget);
+    QPointer<Smb4KSynchronizationDialog> dlg = new Smb4KSynchronizationDialog(m_share, QApplication::activeWindow());
 
     if (dlg->exec() == QDialog::Accepted)
     {
       // Create the destination directory if it does not already exits.
-      if (!QFile::exists(dlg->destination().path()))
+      QDir syncDir(dlg->destination().path());
+      
+      if (!syncDir.exists())
       {
-        QDir syncDir(dlg->destination().path());
-
-        if (!syncDir.mkpath(dlg->destination().path()))
+        if (!QDir().mkpath(syncDir.path()))
         {
           Smb4KNotification::mkdirFailed(syncDir);
           emitResult();
           return;
         }
-        else
-        {
-          // Do nothing
-        }
-      }
-      else
-      {
-        // Do nothing
       }
       
       // Make sure that we have got the trailing slash present.
@@ -186,55 +176,31 @@ void Smb4KSyncJob::slotStartSynchronization()
     {
       command << "--recursive";
     }
-    else
-    {
-      // Do nothing
-    }
 
     if (Smb4KSettings::preserveSymlinks())
     {
       command << "--links";
     }
-    else
-    {
-      // Do nothing
-    }
 
     if (Smb4KSettings::preservePermissions())
     {
       command << "--perms";
     }
-    else
-    {
-      // Do nothing
-    }
 
     if (Smb4KSettings::preserveTimes())
     {
       command << "--times";
     }
-    else
-    {
-      // Do nothing
-    }
 
     if (Smb4KSettings::preserveGroup())
     {
       command << "--group";
     }
-    else
-    {
-      // Do nothing
-    }
 
     if (Smb4KSettings::preserveOwner())
     {
       command << "--owner";
     }
-    else
-    {
-      // Do nothing
-    }
 
     if (Smb4KSettings::preserveDevicesAndSpecials())
     {
@@ -242,38 +208,22 @@ void Smb4KSyncJob::slotStartSynchronization()
       command << "--devices";
       command << "--specials";
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   if (Smb4KSettings::relativePathNames())
   {
     command << "--relative";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::noImpliedDirectories())
   {
     command << "--no-implied-dirs";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::transferDirectories())
   {
     command << "--dirs";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::makeBackups())
   {
@@ -283,23 +233,11 @@ void Smb4KSyncJob::slotStartSynchronization()
     {
       command << QString("--backup-dir=%1").arg(Smb4KSettings::backupDirectory().path());
     }
-    else
-    {
-      // Do nothing
-    }
 
     if (Smb4KSettings::useBackupSuffix())
     {
       command << QString("--suffix=%1").arg(Smb4KSettings::backupSuffix());
     }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else
-  {
-    // Do nothing
   }
   
   //
@@ -309,109 +247,71 @@ void Smb4KSyncJob::slotStartSynchronization()
   {
     command << "--update";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::updateInPlace())
   {
     command << "--inplace";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::efficientSparseFileHandling())
   {
     command << "--sparse";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::copyFilesWhole())
   {
     command << "--whole-file";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::updateExisting())
   {
     command << "--existing";
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::ignoreExisting())
   {
     command << "--ignore-existing";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::transformSymlinks())
   {
     command << "--copy-links";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::transformUnsafeSymlinks())
   {
     command << "--copy-unsafe-links";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::ignoreUnsafeSymlinks())
   {
     command << "--safe-links";
   }
-  else
+  
+  if (Smb4KSettings::mungeSymlinks())
   {
-    // Do nothing
+    command << "--munge-links";
   }
   
   if (Smb4KSettings::preserveHardLinks())
   {
     command << "--hard-links";
   }
-  else
-  {
-    // Do nothing
-  }
   
+  if (Smb4KSettings::copyDirectorySymlinks())
+  {
+    command << "--copy-dirlinks";
+  }
+
   if (Smb4KSettings::keepDirectorySymlinks())
   {
     command << "--keep-dirlinks";
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::omitDirectoryTimes())
   {
     command << "--omit-dir-times";
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // File transfer
@@ -419,29 +319,27 @@ void Smb4KSyncJob::slotStartSynchronization()
   if (Smb4KSettings::compressData())
   {
     command << "--compress";
-  }
-  else
-  {
-    // Do nothing
+  
+    if (Smb4KSettings::useCompressionLevel())
+    {
+      command << QString("--compress-level=%1").arg(Smb4KSettings::compressionLevel());
+    }
+    
+    if (Smb4KSettings::useSkipCompression())
+    {
+      command << QString("--skip-compress=%1").arg(Smb4KSettings::skipCompression());
+    }
   }
   
   if (Smb4KSettings::self()->useMaximalTransferSize())
   {
     command << QString("--max-size=%1K").arg(Smb4KSettings::self()->maximalTransferSize());
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::self()->useMinimalTransferSize())
   {
     command << QString("--min-size=%1K").arg(Smb4KSettings::self()->minimalTransferSize());
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::keepPartial())
   {
@@ -451,14 +349,11 @@ void Smb4KSyncJob::slotStartSynchronization()
     {
       command << QString("--partial-dir=%1").arg(Smb4KSettings::partialDirectory().path());
     }
-    else
-    {
-      // Do nothing
-    }
   }
-  else
+  
+  if (Smb4KSettings::useBandwidthLimit())
   {
-    // Do nothing
+    command << QString("--bwlimit=%1K").arg(Smb4KSettings::bandwidthLimit());
   }
   
   //
@@ -468,82 +363,46 @@ void Smb4KSyncJob::slotStartSynchronization()
   {
     command << "--remove-source-files";
   }
-  else
-  {
-    // Do nothing
-  }  
 
   if (Smb4KSettings::deleteExtraneous())
   {
     command << "--delete";
   }
-  else
-  {
-    // Do nothing
-  }
-  
+
   if (Smb4KSettings::deleteBefore())
   {
     command << "--delete-before";
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::deleteDuring())
   {
     command << "--delete-during";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::deleteAfter())
   {
     command << "--delete-after";
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::deleteExcluded())
   {
     command << "--delete-excluded";
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::ignoreErrors())
   {
     command << "--ignore-errors";
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::forceDirectoryDeletion())
   {
     command << "--force";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::useMaximumDelete())
   {
     command << QString("--max-delete=%1").arg(Smb4KSettings::maximumDeleteValue());
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // Filtering
@@ -552,75 +411,43 @@ void Smb4KSyncJob::slotStartSynchronization()
   {
     command << "--cvs-exclude";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::useExcludePattern())
   {
     command << QString("--exclude=%1").arg(Smb4KSettings::excludePattern());
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::useExcludeFrom())
   {
     command << QString("--exclude-from=%1").arg(Smb4KSettings::excludeFrom().path());
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::useIncludePattern())
   {
     command << QString("--include=%1").arg(Smb4KSettings::includePattern());
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::useIncludeFrom())
   {
     command << QString("--include-from=%1").arg(Smb4KSettings::includeFrom().path());
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (!Smb4KSettings::customFilteringRules().isEmpty())
   {
     qDebug() << "Do we need to spilt the filtering rules into a list?";
     command << Smb4KSettings::customFilteringRules();
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::useFFilterRule())
   {
     command << "-F";
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::useFFFilterRule())
   {
     command << "-F";
     command << "-F";
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // Miscellaneous
@@ -629,48 +456,28 @@ void Smb4KSyncJob::slotStartSynchronization()
   {
     command << QString("--block-size=%1").arg(Smb4KSettings::blockSize());
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::useChecksumSeed())
   {
     command << QString("--checksum-seed=%1").arg(Smb4KSettings::checksumSeed());
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::useChecksum())
   {
     command << "--checksum";
   }
-  else
-  {
-    // Do nothing
-  }
 
   if (Smb4KSettings::oneFileSystem())
   {
     command << "--one-file-system";
   }
-  else
-  {
-    // Do nothing
-  }
   
   if (Smb4KSettings::delayUpdates())
   {
     command << "--delay-updates";
   }
-  else
-  {
-    // Do nothing
-  }
   
-  // Make sure that the trailling slash is present. rsync is very 
+  // Make sure that the trailing slash is present. rsync is very 
   // picky regarding it.
   QString source = m_src.path() + (!m_src.path().endsWith('/') ? "/" : "");
   QString destination = m_dest.path() + (!m_dest.path().endsWith('/') ? "/" : "");
@@ -687,7 +494,8 @@ void Smb4KSyncJob::slotStartSynchronization()
   //
   // The process
   //
-  m_process = new Smb4KProcess(this);
+  m_process = new KProcess(this);
+  m_process->setEnv("LANG", "en_US.UTF-8");
   m_process->setOutputChannelMode(KProcess::SeparateChannels);
   m_process->setProgram(command);
   
@@ -735,10 +543,6 @@ void Smb4KSyncJob::slotReadStandardOutput()
           setTotalAmount(KJob::Files, total);
           emitPercent(total - files, total);
         }
-        else
-        {
-          // Do nothing
-        }
       }
       else if (stdOut.at(i).contains(" to-chk="))
       {
@@ -757,10 +561,6 @@ void Smb4KSyncJob::slotReadStandardOutput()
           setTotalAmount(KJob::Files, total);
           emitPercent(total - files, total);
         }
-        else
-        {
-          // Do nothing
-        }
       }
       else if (stdOut.at(i).contains(" ir-chk="))
       {
@@ -779,14 +579,6 @@ void Smb4KSyncJob::slotReadStandardOutput()
           setTotalAmount(KJob::Files, total);
           emitPercent(total - files, total);
         }
-        else
-        {
-          // Do nothing
-        }
-      }
-      else
-      {
-        // No overall transfer progress can be determined
       }
 
       // Get transfer rate
@@ -798,7 +590,7 @@ void Smb4KSyncJob::slotReadStandardOutput()
 
         if (success)
         {
-          // MB == 1000000 B and kB == 1000 B per definitionem!
+          // MB == 1000000 B and kB == 1000 B per definition!
           if (stdOut.at(i).contains("MB/s"))
           {
             tmp_speed *= 1e6;
@@ -807,22 +599,10 @@ void Smb4KSyncJob::slotReadStandardOutput()
           {
             tmp_speed *= 1e3;
           }
-          else
-          {
-            // Do nothing
-          }
 
           ulong speed = (ulong)tmp_speed;
           emitSpeed(speed /* B/s */);
         }
-        else
-        {
-          // Do nothing
-        }
-      }
-      else
-      {
-        // No transfer rate available
       }
     }
     else if (!stdOut.at(i).contains("sending incremental file list"))
@@ -840,28 +620,31 @@ void Smb4KSyncJob::slotReadStandardOutput()
                        qMakePair(i18n("Source"), src_url.path()),
                        qMakePair(i18n("Destination"), dest_url.path()));
     }
-    else
-    {
-      // Do nothing
-    }
   }
 }
 
 
 void Smb4KSyncJob::slotReadStandardError()
 {
+  //
+  // Get the error message
+  // 
   QString stdErr = QString::fromUtf8(m_process->readAllStandardError(), -1).trimmed();
-
-  // Avoid reporting an error if the process was killed by calling the abort() function.
-  if (!m_process->isAborted() && (stdErr.contains("rsync error:") && !stdErr.contains("(code 23)")
-       /*ignore "some files were not transferred" error*/))
+  
+  //
+  // Make sure the process is terminated
+  // 
+  if (m_process->state() != KProcess::NotRunning)
   {
-    m_process->abort();
-    Smb4KNotification::synchronizationFailed(m_src, m_dest, stdErr);
+    m_process->terminate();
   }
-  else
+  
+  //
+  // Report an error if the process was not terminated
+  // 
+  if (!(stdErr.contains("rsync error") && stdErr.contains("(code 20)")))
   {
-    // Go ahead
+    Smb4KNotification::synchronizationFailed(m_src, m_dest, stdErr);
   }
 }
 
@@ -876,14 +659,7 @@ void Smb4KSyncJob::slotProcessFinished(int, QProcess::ExitStatus status)
   {
     case QProcess::CrashExit:
     {
-      if (!m_process->isAborted())
-      {
-        Smb4KNotification::processError(m_process->error());
-      }
-      else
-      {
-        // Do nothing
-      }
+      Smb4KNotification::processError(m_process->error());
       break;
     }
     default:
@@ -960,15 +736,32 @@ Smb4KSynchronizationDialog::Smb4KSynchronizationDialog(const SharePtr &share, QW
   layout->addWidget(m_destination, 2, 1, 0);
   layout->addWidget(buttonBox, 3, 0, 1, 2, 0);
 
+  // 
   // Connections
+  // 
   connect(m_cancel_button, SIGNAL(clicked()), SLOT(slotCancelClicked()));
   connect(m_synchronize_button, SIGNAL(clicked()), SLOT(slotSynchronizeClicked()));
   connect(m_swap_button, SIGNAL(clicked()), SLOT(slotSwapPathsClicked()));
 
-  setMinimumSize((sizeHint().width() > 350 ? sizeHint().width() : 350), sizeHint().height());
+  //
+  // Set the dialog size
+  // 
+  create();
 
   KConfigGroup group(Smb4KSettings::self()->config(), "SynchronizationDialog");
-  KWindowConfig::restoreWindowSize(windowHandle(), group);
+  QSize dialogSize;
+  
+  if (group.exists())
+  {
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    dialogSize = windowHandle()->size();
+  }
+  else
+  {
+    dialogSize = sizeHint();
+  }
+  
+  resize(dialogSize); // workaround for QTBUG-40584  
 }
 
 
