@@ -2,7 +2,7 @@
     Private helper classes for the wallet manager of Smb4K.
                              -------------------
     begin                : Mo Dez 31 2012
-    copyright            : (C) 2012-2017 by Alexander Reinholdt
+    copyright            : (C) 2012-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -57,10 +57,7 @@ Smb4KPasswordDialog::Smb4KPasswordDialog(const NetworkItemPtr &networkItem, cons
         setPassword(host->password());
         setPrompt(i18n("<qt>Please enter a username and a password for the host <b>%1</b>.</qt>", host->hostName()));
       }
-      else
-      {
-        // Do nothing
-      }
+
       break;
     }
     case Share:
@@ -82,17 +79,14 @@ Smb4KPasswordDialog::Smb4KPasswordDialog(const NetworkItemPtr &networkItem, cons
 
         if (!share->isHomesShare())
         {
-          setPrompt(i18n("<qt>Please enter a username and a password for the share <b>%1</b>.</qt>", share->unc()));
+          setPrompt(i18n("<qt>Please enter a username and a password for the share <b>%1</b>.</qt>", share->displayString()));
         }
         else
         {
-          setPrompt(i18n("<qt>Please enter a username and a password for the share <b>%1</b>.</qt>", share->homeUNC()));
+          setPrompt(i18n("<qt>Please enter a username and a password for the share <b>%1 on %2</b>.</qt>", share->displayString(true)));
         }
       }
-      else
-      {
-        // Do nothing
-      }
+
       break;
     }
     default:
@@ -123,10 +117,7 @@ void Smb4KPasswordDialog::slotGotUsernameAndPassword(const QString &user, const
         host->setLogin(user);
         host->setPassword(pass);
       }
-      else
-      {
-        // Do nothing
-      }
+
       break;
     }
     case Share:
@@ -138,10 +129,7 @@ void Smb4KPasswordDialog::slotGotUsernameAndPassword(const QString &user, const
         share->setLogin(user);
         share->setPassword(pass);
       }
-      else
-      {
-        // Do nothing
-      }
+
       break;
     }
     default:
