@@ -2,7 +2,7 @@
     This class provides the interface for Plasma and QtQuick
                              -------------------
     begin                : Mo 02 Sep 2013
-    copyright            : (C) 2013-2017 by Alexander Reinholdt
+    copyright            : (C) 2013-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -33,7 +33,6 @@
 #include "smb4kbookmarkobject.h"
 #include "smb4knetworkobject.h"
 #include "smb4kprofileobject.h"
-#include "core/smb4kscanner.h"
 #include "core/smb4kmounter.h"
 #include "core/smb4kglobal.h"
 #include "core/smb4kworkgroup.h"
@@ -42,46 +41,51 @@
 #include "core/smb4kbasicnetworkitem.h"
 #include "core/smb4kbookmarkhandler.h"
 #include "core/smb4kbookmark.h"
-#include "core/smb4kprint.h"
 #include "core/smb4kcustomoptionsmanager.h"
 #include "core/smb4kprofilemanager.h"
 #include "core/smb4ksynchronizer.h"
-#include "core/smb4kpreviewer.h"
+#include "core/smb4kclient.h"
 
 // Qt includes
 #include <QDebug>
 #include <QTest>
 
-using namespace Smb4KGlobal;
+// KDE includes
+#include <KCoreAddons/KPluginLoader>
+#include <KCoreAddons/KPluginFactory>
+#include <KConfigWidgets/KConfigDialog>
 
 
 Smb4KDeclarative::Smb4KDeclarative(QObject* parent)
 : QObject(parent), d(new Smb4KDeclarativePrivate)
 {
-  // Initialize the core.
+  // 
+  // Initialize the core
+  // 
   Smb4KGlobal::initCore(true, false);
   
+  // 
   // Connections
-  connect(Smb4KScanner::self(), SIGNAL(workgroups()), this, SLOT(slotWorkgroupsListChanged()));
-  connect(Smb4KScanner::self(), SIGNAL(hosts(WorkgroupPtr)), this, SLOT(slotHostsListChanged()));
-  connect(Smb4KScanner::self(), SIGNAL(shares(HostPtr)), this, SLOT(slotSharesListChanged()));
-  connect(Smb4KScanner::self(), SIGNAL(aboutToStart(NetworkItemPtr,int)), this, SIGNAL(busy()));
-  connect(Smb4KScanner::self(), SIGNAL(finished(NetworkItemPtr,int)), this, SIGNAL(idle()));
+  // 
+  connect(Smb4KClient::self(), SIGNAL(workgroups()), this, SLOT(slotWorkgroupsListChanged()));
+  connect(Smb4KClient::self(), SIGNAL(hosts(WorkgroupPtr)), this, SLOT(slotHostsListChanged()));
+  connect(Smb4KClient::self(), SIGNAL(shares(HostPtr)), this, SLOT(slotSharesListChanged()));
+  connect(Smb4KClient::self(), SIGNAL(aboutToStart(NetworkItemPtr,int)), this, SIGNAL(busy()));
+  connect(Smb4KClient::self(), SIGNAL(finished(NetworkItemPtr,int)), this, SIGNAL(idle()));
   
   connect(Smb4KMounter::self(), SIGNAL(mountedSharesListChanged()), this, SLOT(slotMountedSharesListChanged()));
   connect(Smb4KMounter::self(), SIGNAL(aboutToStart(int)), this, SIGNAL(busy()));
   connect(Smb4KMounter::self(), SIGNAL(finished(int)), this, SIGNAL(idle()));
   
-  connect(Smb4KPrint::self(), SIGNAL(aboutToStart(SharePtr)), this, SIGNAL(busy()));
-  connect(Smb4KPrint::self(), SIGNAL(finished(SharePtr)), this, SIGNAL(idle()));
-  
   connect(Smb4KBookmarkHandler::self(), SIGNAL(updated()), this, SLOT(slotBookmarksListChanged()));
   
   connect(Smb4KProfileManager::self(), SIGNAL(profilesListChanged(QStringList)), this, SLOT(slotProfilesListChanged(QStringList)));
   connect(Smb4KProfileManager::self(), SIGNAL(activeProfileChanged(QString)), this, SLOT(slotActiveProfileChanged(QString)));
   connect(Smb4KProfileManager::self(), SIGNAL(profileUsageChanged(bool)), this, SLOT(slotProfileUsageChanged(bool)));
   
-  // Do the initial loading of items.
+  // 
+  // Do the initial loading of items
+  // 
   slotBookmarksListChanged();
   slotProfilesListChanged(Smb4KProfileManager::self()->profilesList());
   slotActiveProfileChanged(Smb4KProfileManager::self()->activeProfile());
@@ -176,42 +180,36 @@ void Smb4KDeclarative::lookup(Smb4KNetworkObject *object)
   {
     switch (object->type())
     {
-      case Network:
+      case Smb4KNetworkObject::Network:
       {
-        Smb4KScanner::self()->lookupDomains();
+        Smb4KClient::self()->lookupDomains();
         break;
       }
-      case Workgroup:
+      case Smb4KNetworkObject::Workgroup:
       {
         // Check if the workgroup is known.
-        WorkgroupPtr workgroup = findWorkgroup(object->url().host().toUpper());
+        WorkgroupPtr workgroup = Smb4KGlobal::findWorkgroup(object->url().host().toUpper());
         
         if (workgroup)
         {
-          Smb4KScanner::self()->lookupDomainMembers(workgroup);
-        }
-        else
-        {
-          // Do nothing
+          Smb4KClient::self()->lookupDomainMembers(workgroup);
         }
+        
         break;
       }
-      case Host:
+      case Smb4KNetworkObject::Host:
       {
         // Check if the host is known.
-        HostPtr host = findHost(object->url().host().toUpper());
+        HostPtr host = Smb4KGlobal::findHost(object->url().host().toUpper());
         
         if (host)
         {
-          Smb4KScanner::self()->lookupShares(host);
-        }
-        else
-        {
-          // Do nothing
+          Smb4KClient::self()->lookupShares(host);
         }
+        
         break;
       }
-      case Share:
+      case Smb4KNetworkObject::Share:
       {
         break;
       }
@@ -225,7 +223,7 @@ void Smb4KDeclarative::lookup(Smb4KNetworkObject *object)
   else
   {
     // If the object is 0, scan the whole network.
-    Smb4KScanner::self()->lookupDomains();
+    Smb4KClient::self()->lookupDomains();
   }
 }
 
@@ -238,7 +236,7 @@ Smb4KNetworkObject *Smb4KDeclarative::findNetworkItem(const QUrl &url, int type)
   {  
     switch (type)
     {
-      case Workgroup:
+      case Smb4KNetworkObject::Workgroup:
       {
         for (Smb4KNetworkObject *obj : d->workgroupObjects)
         {
@@ -254,7 +252,7 @@ Smb4KNetworkObject *Smb4KDeclarative::findNetworkItem(const QUrl &url, int type)
         }
         break;
       }
-      case Host:
+      case Smb4KNetworkObject::Host:
       {
         for (Smb4KNetworkObject *obj : d->hostObjects)
         {
@@ -270,7 +268,7 @@ Smb4KNetworkObject *Smb4KDeclarative::findNetworkItem(const QUrl &url, int type)
         }
         break;
       }
-      case Share:
+      case Smb4KNetworkObject::Share:
       {
         for (Smb4KNetworkObject *obj : d->shareObjects)
         {
@@ -292,18 +290,14 @@ Smb4KNetworkObject *Smb4KDeclarative::findNetworkItem(const QUrl &url, int type)
       }
     }
   }
-  else
-  {
-    // Do nothing
-  }
   
   return object;
 }
 
 
-void Smb4KDeclarative::openMountDialog(QWidget* parent)
+void Smb4KDeclarative::openMountDialog()
 {
-  Smb4KMounter::self()->openMountDialog(parent);
+  Smb4KMounter::self()->openMountDialog();
 }
 
 
@@ -317,12 +311,8 @@ void Smb4KDeclarative::mount(Smb4KNetworkObject *object)
     {
       shareName = shareName.mid(1, -1);
     }
-    else
-    {
-      // Do nothing
-    }
       
-    SharePtr share = findShare("//"+object->hostName()+'/'+object->shareName(), object->workgroupName());
+    SharePtr share = Smb4KGlobal::findShare(object->url(), object->workgroupName());
     
     if (share)
     {
@@ -332,13 +322,12 @@ void Smb4KDeclarative::mount(Smb4KNetworkObject *object)
     {
       // If the share is not in the global list of shares,
       // try the list of bookmarks.
-      QString unc("//"+object->hostName()+"/"+object->shareName());
-      BookmarkPtr bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUNC(unc);
+      BookmarkPtr bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUrl(object->url());
       
       share = SharePtr(new Smb4KShare());
-      share->setURL(object->url());
+      share->setUrl(object->url());
       share->setWorkgroupName(bookmark->workgroupName());
-      share->setHostIP(bookmark->hostIP());
+      share->setHostIpAddress(bookmark->hostIpAddress());
       Smb4KMounter::self()->mountShare(share);
       
       while (Smb4KMounter::self()->isRunning())
@@ -349,10 +338,6 @@ void Smb4KDeclarative::mount(Smb4KNetworkObject *object)
       share.clear();      
     }
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -362,28 +347,20 @@ void Smb4KDeclarative::unmount(Smb4KNetworkObject *object)
   {
     if (object->mountpoint().isValid())
     {
-      SharePtr share = findShareByPath(object->mountpoint().path());
+      SharePtr share = Smb4KGlobal::findShareByPath(object->mountpoint().path());
       
       if (share)
       {
         Smb4KMounter::self()->unmountShare(share);
       }
-      else
-      {
-        // Do nothing
-      }
     }
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
 void Smb4KDeclarative::unmountAll()
 {
-  Smb4KMounter::self()->unmountAllShares(false, 0);
+  Smb4KMounter::self()->unmountAllShares(false);
 }
 
 
@@ -411,10 +388,6 @@ Smb4KNetworkObject* Smb4KDeclarative::findMountedShare(const QUrl& url, bool exa
       }
     }
   }
-  else
-  {
-    // Do nothing
-  }
   
   return object;
 }
@@ -424,20 +397,12 @@ void Smb4KDeclarative::print(Smb4KNetworkObject* object)
 {
   if (object && object->type() == Smb4KNetworkObject::Share)
   {
-    SharePtr printer = findShare("//"+object->hostName()+"/"+object->shareName(), object->workgroupName());
+    SharePtr printer = Smb4KGlobal::findShare(object->url(), object->workgroupName());
     
     if (printer)
     {
-      Smb4KPrint::self()->print(printer, 0);
+      Smb4KClient::self()->openPrintDialog(printer);
     }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else
-  {
-    // Do nothing
   }
 }
 
@@ -449,7 +414,7 @@ void Smb4KDeclarative::addBookmark(Smb4KNetworkObject* object)
     QList<SharePtr> shares; 
     
     // First, search the list of shares gathered by the scanner.
-    for (const SharePtr &share : sharesList())
+    for (const SharePtr &share : Smb4KGlobal::sharesList())
     {
       if (share->url() == object->url())
       {
@@ -465,7 +430,7 @@ void Smb4KDeclarative::addBookmark(Smb4KNetworkObject* object)
     // Second, if the list is still empty, try the list of mounted shares.
     if (shares.isEmpty())
     {
-      for (const SharePtr &mountedShare : mountedSharesList())
+      for (const SharePtr &mountedShare : Smb4KGlobal::mountedSharesList())
       {
         if (mountedShare->url() == object->url())
         {
@@ -478,24 +443,17 @@ void Smb4KDeclarative::addBookmark(Smb4KNetworkObject* object)
         }
       }
     }
-    else
-    {
-      // Do nothing
-    }
     
     // Now add the share.
     if (!shares.isEmpty())
     {
-      Smb4KBookmarkHandler::self()->addBookmarks(shares, 0);
+      for (const SharePtr &p : shares)
+      {
+        qDebug() << p->url();
+      }
+      
+      Smb4KBookmarkHandler::self()->addBookmarks(shares);
     }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else
-  {
-    // Do nothing
   }
 }
 
@@ -504,30 +462,16 @@ void Smb4KDeclarative::removeBookmark(Smb4KBookmarkObject* object)
 {
   if (object)
   {
+    // 
     // Find the bookmark in the list and remove it.
-    QString path = (object->url().path().startsWith('/') ? object->url().path().remove(0, 1) : object->url().path());
-    QString unc = QString("//%1/%2").arg(object->url().host().toUpper()).arg(path);
-    BookmarkPtr bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUNC(unc);
+    // 
+    BookmarkPtr bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUrl(object->url());
     
     if (bookmark)
     {
       Smb4KBookmarkHandler::self()->removeBookmark(bookmark);
     }
-    else
-    {
-      // Do nothing
-    }
   }
-  else
-  {
-    // Do nothing
-  }
-}
-
-
-void Smb4KDeclarative::removeBookmarkGroup(const QString& name)
-{
-  Smb4KBookmarkHandler::self()->removeGroup(name);
 }
 
 
@@ -541,22 +485,14 @@ void Smb4KDeclarative::synchronize(Smb4KNetworkObject* object)
 {
   if (object && object->type() == Smb4KNetworkObject::Share)
   {
-    for (const SharePtr &share : mountedSharesList())
+    for (const SharePtr &share : Smb4KGlobal::mountedSharesList())
     {
       if (share->url() == object->url())
       {
         Smb4KSynchronizer::self()->synchronize(share);
       }
-      else
-      {
-        // Do nothing
-      }
     }
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -568,7 +504,7 @@ void Smb4KDeclarative::openCustomOptionsDialog(Smb4KNetworkObject *object)
     {
       case Smb4KNetworkObject::Host:
       {
-        for (const HostPtr &host : hostsList())
+        for (const HostPtr &host : Smb4KGlobal::hostsList())
         {
           if (host->url() == object->url())
           {
@@ -584,7 +520,7 @@ void Smb4KDeclarative::openCustomOptionsDialog(Smb4KNetworkObject *object)
       }
       case Smb4KNetworkObject::Share:
       {
-        for (const SharePtr &share : sharesList())
+        for (const SharePtr &share : Smb4KGlobal::sharesList())
         {
           if (share->url() == object->url())
           {
@@ -604,22 +540,18 @@ void Smb4KDeclarative::openCustomOptionsDialog(Smb4KNetworkObject *object)
       }
     }
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
-void Smb4KDeclarative::startScanner()
+void Smb4KDeclarative::startClient()
 {
-  Smb4KScanner::self()->start();
+  Smb4KClient::self()->start();
 }
 
 
-void Smb4KDeclarative::abortScanner()
+void Smb4KDeclarative::abortClient()
 {
-  Smb4KScanner::self()->abortAll();
+  Smb4KClient::self()->abort();
 }
 
 
@@ -631,19 +563,7 @@ void Smb4KDeclarative::startMounter()
 
 void Smb4KDeclarative::abortMounter()
 {
-  Smb4KMounter::self()->abortAll();
-}
-
-
-void Smb4KDeclarative::startPrinter()
-{
-  Smb4KPrint::self()->start();
-}
-
-
-void Smb4KDeclarative::abortPrinter()
-{
-  Smb4KPrint::self()->abortAll();
+  Smb4KMounter::self()->abort();
 }
 
 
@@ -684,25 +604,45 @@ void Smb4KDeclarative::preview(Smb4KNetworkObject* object)
 {
   if (object->type() == Smb4KNetworkObject::Share)
   {
-    QString unc = object->url().toString(QUrl::RemoveScheme|QUrl::RemoveUserInfo|QUrl::RemovePort|QUrl::StripTrailingSlash);
-    SharePtr share = findShare(unc, object->workgroupName());
+    SharePtr share = Smb4KGlobal::findShare(object->url(), object->workgroupName());
     
     if (share)
     {
-      Smb4KPreviewer::self()->preview(share);
+      Smb4KClient::self()->openPreviewDialog(share);
     }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else
-  {
-    // Do nothing
   }
 }
 
 
+void Smb4KDeclarative::openConfigurationDialog()
+{
+  //
+  // Check if the configuration dialog exists and try to show it.
+  //
+  if (KConfigDialog::exists("Smb4KConfigDialog"))
+  {
+    KConfigDialog::showDialog("Smb4KConfigDialog");
+    return;
+  }
+  
+  //
+  // If the dialog does not exist, load and show it:
+  //
+  KPluginLoader loader("smb4kconfigdialog", this);
+  KPluginFactory *configFactory = loader.factory();
+
+  if (configFactory)
+  {
+    KConfigDialog *dlg = configFactory->create<KConfigDialog>();
+    
+    if (dlg)
+    {
+      dlg->setObjectName("Smb4KConfigDialog");
+      dlg->show();
+    }
+  }
+}
+
 
 void Smb4KDeclarative::slotWorkgroupsListChanged()
 {
@@ -712,7 +652,7 @@ void Smb4KDeclarative::slotWorkgroupsListChanged()
     delete d->workgroupObjects.takeFirst();
   }
 
-  for (const WorkgroupPtr &workgroup : workgroupsList())
+  for (const WorkgroupPtr &workgroup : Smb4KGlobal::workgroupsList())
   {
     d->workgroupObjects << new Smb4KNetworkObject(workgroup.data());
   }
@@ -729,7 +669,7 @@ void Smb4KDeclarative::slotHostsListChanged()
     delete d->hostObjects.takeFirst();
   }
   
-  for (const HostPtr &host : hostsList())
+  for (const HostPtr &host : Smb4KGlobal::hostsList())
   {
     d->hostObjects << new Smb4KNetworkObject(host.data());
   }
@@ -746,7 +686,7 @@ void Smb4KDeclarative::slotSharesListChanged()
     delete d->shareObjects.takeFirst();
   }
 
-  for (const SharePtr &share : sharesList())
+  for (const SharePtr &share : Smb4KGlobal::sharesList())
   {
     d->shareObjects << new Smb4KNetworkObject(share.data());
   }
@@ -763,7 +703,7 @@ void Smb4KDeclarative::slotMountedSharesListChanged()
     delete d->mountedObjects.takeFirst();
   }
   
-  for (const SharePtr &mountedShare : mountedSharesList())
+  for (const SharePtr &mountedShare : Smb4KGlobal::mountedSharesList())
   {
     d->mountedObjects << new Smb4KNetworkObject(mountedShare.data());
   }
