@@ -2,7 +2,7 @@
     This class provides the interface for Plasma and QtQuick
                              -------------------
     begin                : Mo 02 Sep 2013
-    copyright            : (C) 2013-2017 by Alexander Reinholdt
+    copyright            : (C) 2013-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -30,6 +30,7 @@
 #include <QObject>
 #include <QUrl>
 #include <QQmlListProperty>
+#include <QQmlListReference>
 
 // forward declarations
 class Smb4KDeclarativePrivate;
@@ -164,10 +165,8 @@ class Q_DECL_EXPORT Smb4KDeclarative : public QObject
     
     /**
      * Open the mount dialog to mount a share.
-     * 
-     * @param parent      The parent of this dialog.
      */
-    Q_INVOKABLE void openMountDialog(QWidget *parent = 0);
+    Q_INVOKABLE void openMountDialog();
     
     /**
      * This function takes a network object and initiates the mounting of 
@@ -239,14 +238,7 @@ class Q_DECL_EXPORT Smb4KDeclarative : public QObject
     Q_INVOKABLE void removeBookmark(Smb4KBookmarkObject *object);
     
     /**
-     * This function removes a bookmark group.
-     * 
-     * @param name          The name of the bookmark group
-     */
-    Q_INVOKABLE void removeBookmarkGroup(const QString &name);
-    
-    /**
-     * This function invokes the bookmark editor.
+     * This function opens the bookmark editor.
      */
     Q_INVOKABLE void editBookmarks();
     
@@ -264,14 +256,14 @@ class Q_DECL_EXPORT Smb4KDeclarative : public QObject
     Q_INVOKABLE void openCustomOptionsDialog(Smb4KNetworkObject *object);
     
     /**
-     * This function starts the scanner.
+     * This function starts the client
      */
-    Q_INVOKABLE void startScanner();
+    Q_INVOKABLE void startClient();
     
     /**
-     * This function aborts any action of the scanner.
+     * This function stops the client
      */
-    Q_INVOKABLE void abortScanner();
+    Q_INVOKABLE void abortClient();
     
     /**
      * This function starts the mounter.
@@ -279,20 +271,10 @@ class Q_DECL_EXPORT Smb4KDeclarative : public QObject
     Q_INVOKABLE void startMounter();
     
     /**
-     * This function aborts any action of the mounter.
+     * This function stops any action of the mounter.
      */
     Q_INVOKABLE void abortMounter();
     
-    /**
-     * This function starts the printer interface.
-     */
-    Q_INVOKABLE void startPrinter();
-    
-    /**
-     * This function aborts any actions of the printer interface.
-     */
-    Q_INVOKABLE void abortPrinter();
-    
     /**
      * Return the currently active profile or an empty string if 
      * the use of profiles is disabled.
@@ -320,6 +302,11 @@ class Q_DECL_EXPORT Smb4KDeclarative : public QObject
      * @param object        The network object
      */
     Q_INVOKABLE void preview(Smb4KNetworkObject *object);
+    
+    /**
+     * Open the configuration dialog of the main application
+     */
+    Q_INVOKABLE void openConfigurationDialog();
 
   Q_SIGNALS:
     /**
