@@ -151,7 +151,7 @@ int main(int argc, char **argv)
   KAboutData aboutData(QStringLiteral("smb4k"), i18n("Smb4K"), QStringLiteral(VERSION),
     i18n("Advanced network neighborhood browser and Samba share mounting utility"),
     KAboutLicense::GPL_V2, i18n("\u00A9 2003-2019 Alexander Reinholdt"), QString(), 
-    QStringLiteral("http://smb4k.sourceforge.net"));
+    QStringLiteral("https://smb4k.sourceforge.io"));
   
   // DBus prefix
   aboutData.setOrganizationDomain("kde.org");
