@@ -2,7 +2,7 @@
     smb4kbookmarkmenu  -  Bookmark menu
                              -------------------
     begin                : Sat Apr 02 2011
-    copyright            : (C) 2011-2018 by Alexander Reinholdt
+    copyright            : (C) 2011-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -98,10 +98,6 @@ void Smb4KBookmarkMenu::refreshMenu()
   {
     menu()->clear();
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // Set up the menu
@@ -115,42 +111,17 @@ void Smb4KBookmarkMenu::refreshMenu()
 }
 
 
-void Smb4KBookmarkMenu::customEvent(QEvent* e)
+void Smb4KBookmarkMenu::setBookmarkActionEnabled(bool enable)
 {
-  if (e->type() == Smb4KEvent::EnableBookmarkAction)
-  {
-    QAction *action = menu()->findChild<QAction *>("add_action");
+  QAction *action = menu()->findChild<QAction *>("add_action");
     
-    if (action)
-    {
-      action->setEnabled(true);
-    }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else if (e->type() == Smb4KEvent::DisableBookmarkAction)
+  if (action)
   {
-    QAction *action = menu()->findChild<QAction *>("add_action");
-    
-    if (action)
-    {
-      action->setEnabled(false);
-    }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else
-  {
-    // Do nothing
+    action->setEnabled(enable);
   }
 }
 
 
-
 void Smb4KBookmarkMenu::setupMenu()
 {
   //
@@ -175,6 +146,7 @@ void Smb4KBookmarkMenu::setupMenu()
       QMap<QString,QVariant> addInfo;
       addInfo["type"] = "add";
       addBookmarkAction->setData(addInfo);
+      addBookmarkAction->setEnabled(false);
       connect(addBookmarkAction, SIGNAL(triggered(bool)), SLOT(slotAddActionTriggered(bool)));
       addAction(addBookmarkAction);
       m_actions->addAction(addBookmarkAction);
@@ -226,7 +198,7 @@ void Smb4KBookmarkMenu::setupMenu()
     
     for (const BookmarkPtr &bookmark : bookmarks)
     {
-      QList<SharePtr> mountedShares = findShareByUNC(bookmark->unc());
+      QList<SharePtr> mountedShares = findShareByUrl(bookmark->url());
       
       if (!mountedShares.isEmpty())
       {
@@ -243,18 +215,10 @@ void Smb4KBookmarkMenu::setupMenu()
           }
         }
       }
-      else
-      {
-        // Do nothing
-      }
     }
     
     toplevelMount->setEnabled(mountedBookmarks != bookmarks.size());
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // Add a separator
@@ -301,11 +265,11 @@ void Smb4KBookmarkMenu::setupMenu()
         if (Smb4KSettings::showCustomBookmarkLabel() && !bookmark->label().isEmpty())
         {
           bookmarkAction = new QAction(bookmark->icon(), bookmark->label(), bookmarkGroupMenu->menu());
-          bookmarkAction->setObjectName(bookmark->unc());
+          bookmarkAction->setObjectName(bookmark->url().toDisplayString());
           QMap<QString,QVariant> bookmarkInfo;
           bookmarkInfo["type"] = "bookmark";
           bookmarkInfo["group"] = group;
-          bookmarkInfo["unc"] = bookmark->unc();
+          bookmarkInfo["url"] = bookmark->url();
           bookmarkInfo["text"] = bookmark->label();
           bookmarkAction->setData(bookmarkInfo);
           m_bookmarks->addAction(bookmarkAction);
@@ -314,18 +278,18 @@ void Smb4KBookmarkMenu::setupMenu()
         else
         {
           bookmarkAction = new QAction(bookmark->icon(), bookmark->displayString(), bookmarkGroupMenu->menu());
-          bookmarkAction->setObjectName(bookmark->unc());
+          bookmarkAction->setObjectName(bookmark->url().toDisplayString());
           QMap<QString,QVariant> bookmarkInfo;
           bookmarkInfo["type"] = "bookmark";
           bookmarkInfo["group"] = group;
-          bookmarkInfo["unc"] = bookmark->unc();
+          bookmarkInfo["url"] = bookmark->url();
           bookmarkInfo["text"] = bookmark->displayString();
           bookmarkAction->setData(bookmarkInfo);
           m_bookmarks->addAction(bookmarkAction);
           sortedBookmarks << bookmark->displayString();
         }
         
-        QList<SharePtr> mountedShares = findShareByUNC(bookmark->unc());
+        QList<SharePtr> mountedShares = findShareByUrl(bookmark->url());
         
         if (!mountedShares.isEmpty())
         {
@@ -343,10 +307,6 @@ void Smb4KBookmarkMenu::setupMenu()
             }
           }
         }
-        else
-        {
-          // Do nothing
-        }
       }
       
       bookmarkGroupMount->setEnabled(mountedBookmarks != bookmarks.size());
@@ -374,10 +334,6 @@ void Smb4KBookmarkMenu::setupMenu()
         }
       }
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   //
@@ -394,11 +350,11 @@ void Smb4KBookmarkMenu::setupMenu()
     if (Smb4KSettings::showCustomBookmarkLabel() && !bookmark->label().isEmpty())
     {
       bookmarkAction = new QAction(bookmark->icon(), bookmark->label(), menu());
-      bookmarkAction->setObjectName(bookmark->unc());
+      bookmarkAction->setObjectName(bookmark->url().toDisplayString());
       QMap<QString,QVariant> bookmarkInfo;
       bookmarkInfo["type"] = "bookmark";
       bookmarkInfo["group"] = "";
-      bookmarkInfo["unc"] = bookmark->unc();
+      bookmarkInfo["url"] = bookmark->url();
       bookmarkInfo["text"] = bookmark->label();
       bookmarkAction->setData(bookmarkInfo);
       m_bookmarks->addAction(bookmarkAction);
@@ -407,18 +363,18 @@ void Smb4KBookmarkMenu::setupMenu()
     else
     {
       bookmarkAction = new QAction(bookmark->icon(), bookmark->displayString(), menu());
-      bookmarkAction->setObjectName(bookmark->unc());
+      bookmarkAction->setObjectName(bookmark->url().toDisplayString());
       QMap<QString,QVariant> bookmarkInfo;
       bookmarkInfo["type"] = "bookmark";
       bookmarkInfo["group"] = "";
-      bookmarkInfo["unc"] = bookmark->unc();
+      bookmarkInfo["url"] = bookmark->url();
       bookmarkInfo["text"] = bookmark->displayString();
       bookmarkAction->setData(bookmarkInfo);
       m_bookmarks->addAction(bookmarkAction);
       sortedBookmarks << bookmark->displayString();
     }
         
-    QList<SharePtr> mountedShares = findShareByUNC(bookmark->unc());
+    QList<SharePtr> mountedShares = findShareByUrl(bookmark->url());
         
     if (!mountedShares.isEmpty())
     {
@@ -435,10 +391,6 @@ void Smb4KBookmarkMenu::setupMenu()
         }
       }
     }
-    else
-    {
-      // Do nothing
-    }
   }
   
   sortedBookmarks.sort();
@@ -469,18 +421,13 @@ void Smb4KBookmarkMenu::setupMenu()
 
 void Smb4KBookmarkMenu::slotEditActionTriggered(bool /*checked*/)
 {
-  //
-  // Edit the bookmarks
-  //
-  Smb4KBookmarkHandler::self()->editBookmarks(m_parent_widget);
+  Smb4KBookmarkHandler::self()->editBookmarks();
 }
 
 
 void Smb4KBookmarkMenu::slotAddActionTriggered(bool /*checked*/)
 {
-  //
-  // Unused at the moment
-  // 
+  emit addBookmark();
 }
 
 
@@ -500,7 +447,7 @@ void Smb4KBookmarkMenu::slotToplevelMountActionTriggered(bool /*checked*/)
     share->setHostName(bookmark->hostName());
     share->setShareName(bookmark->shareName());
     share->setWorkgroupName(bookmark->workgroupName());
-    share->setHostIP(bookmark->hostIP());
+    share->setHostIpAddress(bookmark->hostIpAddress());
     share->setLogin(bookmark->login());
     mounts << share;
   }
@@ -531,7 +478,7 @@ void Smb4KBookmarkMenu::slotGroupActionTriggered(QAction *action)
       share->setHostName(bookmark->hostName());
       share->setShareName(bookmark->shareName());
       share->setWorkgroupName(bookmark->workgroupName());
-      share->setHostIP(bookmark->hostIP());
+      share->setHostIpAddress(bookmark->hostIpAddress());
       share->setLogin(bookmark->login());
       mounts << share;
     }
@@ -543,10 +490,6 @@ void Smb4KBookmarkMenu::slotGroupActionTriggered(QAction *action)
       mounts.takeFirst().clear();
     }
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -554,9 +497,9 @@ void Smb4KBookmarkMenu::slotBookmarkActionTriggered(QAction *action)
 {
   QMap<QString,QVariant> info = action->data().toMap();
   QString bookmarkGroup = info.value("group").toString();
-  QString unc = info.value("unc").toString();
+  QUrl url = info.value("url").toUrl();
   
-  BookmarkPtr bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUNC(unc);
+  BookmarkPtr bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUrl(url);
 
   if (bookmark && bookmarkGroup == bookmark->groupName())
   {
@@ -564,15 +507,11 @@ void Smb4KBookmarkMenu::slotBookmarkActionTriggered(QAction *action)
     share->setHostName(bookmark->hostName());
     share->setShareName(bookmark->shareName());
     share->setWorkgroupName(bookmark->workgroupName());
-    share->setHostIP(bookmark->hostIP());
+    share->setHostIpAddress(bookmark->hostIpAddress());
     share->setLogin(bookmark->login());
     Smb4KMounter::self()->mountShare(share);
     share.clear();
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -594,16 +533,12 @@ void Smb4KBookmarkMenu::slotEnableBookmark(const SharePtr &share)
     
     for (QAction *a : actions)
     {
-      if (share->unc() == a->data().toMap().value("unc").toString())
+      if (share->url() == a->data().toMap().value("url").toUrl())
       {
         a->setEnabled(!share->isMounted());
         bookmarkGroup = a->data().toMap().value("group").toString();
         break;
       }
-      else
-      {
-        // Do nothing
-      }
     }
     
     //
@@ -646,9 +581,5 @@ void Smb4KBookmarkMenu::slotEnableBookmark(const SharePtr &share)
       }
     }
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
