@@ -2,7 +2,7 @@
     smb4kbookmarkmenu  -  Bookmark menu
                              -------------------
     begin                : Sat Apr 02 2011
-    copyright            : (C) 2011-2018 by Alexander Reinholdt
+    copyright            : (C) 2011-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -32,6 +32,7 @@
 // Qt includes
 #include <QAction>
 #include <QActionGroup>
+#include <QPointer>
 
 // KDE includes
 #include <KWidgetsAddons/KActionMenu>
@@ -71,13 +72,18 @@ class Smb4KBookmarkMenu : public KActionMenu
      */
     void refreshMenu();
     
-  protected:
     /**
-     * Reimplemented
+     * Enable/disable the 'Add Bookmark' action
      */
-    void customEvent(QEvent *e);
+    void setBookmarkActionEnabled(bool enable);
+    
+  Q_SIGNALS:
+    /**
+     * This signal is emitted when the 'Add Bookmark' is triggered.
+     */
+    void addBookmark();
 
-  protected slots:
+  protected Q_SLOTS:
     /**
      * Called when the edit action is triggered
      */
