@@ -2,7 +2,7 @@
     The configuration dialog of Smb4K
                              -------------------
     begin                : Sa Apr 14 2007
-    copyright            : (C) 2004-2017 by Alexander Reinholdt
+    copyright            : (C) 2004-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -34,23 +34,20 @@
 #include "smb4kconfigpagemounting.h"
 #include "smb4kconfigpagenetwork.h"
 #include "smb4kconfigpageprofiles.h"
-#include "smb4kconfigpagesamba.h"
-#include "smb4kconfigpageshares.h"
 #include "smb4kconfigpagesynchronization.h"
 #include "smb4kconfigpageuserinterface.h"
 #include "core/smb4ksettings.h"
 #include "core/smb4kglobal.h"
 #include "core/smb4kauthinfo.h"
 #include "core/smb4kwalletmanager.h"
+#include "core/smb4kcustomoptions.h"
 #include "core/smb4kcustomoptionsmanager.h"
 #include "core/smb4kprofilemanager.h"
 
 #if defined(Q_OS_LINUX)
-#include "core/smb4kmountsettings_linux.h"
+#include "smb4kmountsettings_linux.h"
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
-#include "core/smb4kmountsettings_freebsd.h"
-#else
-#define UNSUPPORTED_PLATFORM
+#include "smb4kmountsettings_bsd.h"
 #endif
 
 // Qt includes
@@ -64,6 +61,7 @@
 #include <QTreeWidget>
 #include <QScrollArea>
 #include <QShowEvent>
+#include <QWindow>
 
 // KDE includes
 #include <KCoreAddons/KPluginFactory>
@@ -110,12 +108,12 @@ void Smb4KConfigDialog::setupDialog()
   network_area->setWidget(network_options);
   network_area->setWidgetResizable(true);
   network_area->setFrameStyle(QFrame::NoFrame);
-
-  Smb4KConfigPageShares *share_options = new Smb4KConfigPageShares(this);
-  QScrollArea *share_area = new QScrollArea(this);
-  share_area->setWidget(share_options);
-  share_area->setWidgetResizable(true);
-  share_area->setFrameStyle(QFrame::NoFrame);
+  
+  Smb4KConfigPageMounting *mount_options = new Smb4KConfigPageMounting(this);
+  QScrollArea *mount_area = new QScrollArea(this);
+  mount_area->setWidget(mount_options);
+  mount_area->setWidgetResizable(true);
+  mount_area->setFrameStyle(QFrame::NoFrame);
 
   Smb4KConfigPageAuthentication *auth_options = new Smb4KConfigPageAuthentication(this);
   QScrollArea *auth_area = new QScrollArea(this);
@@ -123,20 +121,6 @@ void Smb4KConfigDialog::setupDialog()
   auth_area->setWidgetResizable(true);
   auth_area->setFrameStyle(QFrame::NoFrame);
 
-  Smb4KConfigPageSamba *samba_options = new Smb4KConfigPageSamba(this);
-  QScrollArea *samba_area = new QScrollArea(this);
-  samba_area->setWidget(samba_options);
-  samba_area->setWidgetResizable(true);
-  samba_area->setFrameStyle(QFrame::NoFrame);
-
-#if !defined(UNSUPPORTED_PLATFORM)  
-  Smb4KConfigPageMounting *mount_options = new Smb4KConfigPageMounting(this);
-  QScrollArea *mount_area = new QScrollArea(this);
-  mount_area->setWidget(mount_options);
-  mount_area->setWidgetResizable(true);
-  mount_area->setFrameStyle(QFrame::NoFrame);
-#endif
-
   Smb4KConfigPageSynchronization *rsync_options = new Smb4KConfigPageSynchronization(this);
   QScrollArea *rsync_area = new QScrollArea(this);
   rsync_area->setWidget(rsync_options);
@@ -162,12 +146,8 @@ void Smb4KConfigDialog::setupDialog()
   // 
   m_user_interface  = addPage(interface_area, Smb4KSettings::self(), i18n("User Interface"), "preferences-desktop");
   m_network         = addPage(network_area, Smb4KSettings::self(), i18n("Network"), "network-workgroup");
-  m_shares          = addPage(share_area, Smb4KSettings::self(), i18n("Shares"), "folder-network");
-  m_authentication  = addPage(auth_area, Smb4KSettings::self(), i18n("Authentication"), "dialog-password");
-  m_samba           = addPage(samba_area, Smb4KSettings::self(), i18n("Samba"), "preferences-system-network-sharing");
-#if !defined(UNSUPPORTED_PLATFORM)
   m_mounting        = addPage(mount_area, Smb4KMountSettings::self(), i18n("Mounting"), "system-run");
-#endif
+  m_authentication  = addPage(auth_area, Smb4KSettings::self(), i18n("Authentication"), "dialog-password");
   m_synchronization = addPage(rsync_area, Smb4KSettings::self(),i18n("Synchronization"), "folder-sync");
   m_custom_options  = addPage(custom_area, Smb4KSettings::self(), i18n("Custom Options"), "preferences-system-network");
   m_profiles        = addPage(profiles_area, Smb4KSettings::self(), i18n("Profiles"), "format-list-unordered");
@@ -176,7 +156,6 @@ void Smb4KConfigDialog::setupDialog()
   // Connections
   // 
   connect(custom_options, SIGNAL(customSettingsModified()), this, SLOT(slotEnableApplyButton()));
-  connect(custom_options, SIGNAL(reloadCustomSettings()), this, SLOT(slotReloadCustomOptions()));
 
   connect(auth_options, SIGNAL(loadWalletEntries()), this, SLOT(slotLoadAuthenticationInformation()));
   connect(auth_options, SIGNAL(saveWalletEntries()), this, SLOT(slotSaveAuthenticationInformation()));
@@ -188,10 +167,12 @@ void Smb4KConfigDialog::setupDialog()
   //
   // Dialog size
   //
-  resize(QSize(800, 600));
+  create();
+  windowHandle()->resize(QSize(800, 600));
 
   KConfigGroup group(Smb4KSettings::self()->config(), "ConfigDialog");
   KWindowConfig::restoreWindowSize(windowHandle(), group);
+  resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 
@@ -202,10 +183,6 @@ void Smb4KConfigDialog::loadCustomOptions()
     QList<OptionsPtr> options = Smb4KCustomOptionsManager::self()->customOptions();
     m_custom_options->widget()->findChild<Smb4KConfigPageCustomOptions *>()->insertCustomOptions(options);
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -216,10 +193,6 @@ void Smb4KConfigDialog::saveCustomOptions()
     QList<OptionsPtr> options = m_custom_options->widget()->findChild<Smb4KConfigPageCustomOptions *>()->getCustomOptions();
     Smb4KCustomOptionsManager::self()->replaceCustomOptions(options);
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -234,13 +207,9 @@ void Smb4KConfigDialog::propagateProfilesChanges()
     
     if (!removed_profiles.isEmpty())
     {
-      Smb4KProfileManager::self()->removeProfiles(removed_profiles, this);
+      Smb4KProfileManager::self()->removeProfiles(removed_profiles);
       profiles_page->clearRemovedProfiles();
     }
-    else
-    {
-      // Do nothing
-    }
     
     // Rename the profiles.
     QList< QPair<QString,QString> > renamed_profiles = profiles_page->renamedProfiles();
@@ -250,24 +219,12 @@ void Smb4KConfigDialog::propagateProfilesChanges()
       Smb4KProfileManager::self()->migrateProfiles(renamed_profiles);
       profiles_page->clearRenamedProfiles();
     }
-    else
-    {
-      // Do nothing
-    }
     
     // Finally reload the custom options.
     if (!removed_profiles.isEmpty() || !renamed_profiles.isEmpty())
     {
       loadCustomOptions();
     }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else
-  {
-    // Do nothing
   }
 }
 
@@ -287,10 +244,6 @@ bool Smb4KConfigDialog::checkNetworkPage()
     custom_master_input->setFocus();
     return false;
   }
-  else
-  {
-    // Do nothing
-  }
   
   QRadioButton *scan_bcast_areas = m_network->widget()->findChild<QRadioButton *>("kcfg_ScanBroadcastAreas");
   KLineEdit *bcast_areas_input   = m_network->widget()->findChild<KLineEdit *>("kcfg_BroadcastAreas");
@@ -303,32 +256,6 @@ bool Smb4KConfigDialog::checkNetworkPage()
     bcast_areas_input->setFocus();
     return false;
   }
-  else
-  {
-    // Do nothing
-  }  
-  
-  return true;
-}
-
-
-bool Smb4KConfigDialog::checkSharesPage()
-{
-  KUrlRequester *mount_prefix = m_shares->widget()->findChild<KUrlRequester *>("kcfg_MountPrefix");
-  
-  QString msg = i18n("<qt>An incorrect setting has been found. You are now taken to the corresponding configuration page to fix it.</qt>");
-  
-  if (mount_prefix && mount_prefix->url().path().trimmed().isEmpty())
-  {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_shares);
-    mount_prefix->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
   
   return true;
 }
@@ -336,11 +263,22 @@ bool Smb4KConfigDialog::checkSharesPage()
 
 bool Smb4KConfigDialog::checkMountingPage()
 {
-#if !defined(UNSUPPORTED_PLATFORM)
-  KLineEdit *file_mask = m_mounting->widget()->findChild<KLineEdit *>("kcfg_FileMask");
+  KUrlRequester *mount_prefix = m_mounting->widget()->findChild<KUrlRequester *>("kcfg_MountPrefix");
   
   QString msg = i18n("<qt>An incorrect setting has been found. You are now taken to the corresponding configuration page to fix it.</qt>");
   
+  if (mount_prefix && mount_prefix->url().path().trimmed().isEmpty())
+  {
+    KMessageBox::sorry(this, msg);
+    setCurrentPage(m_mounting);
+    mount_prefix->setFocus();
+    return false;
+  }
+  
+  KLineEdit *file_mask = m_mounting->widget()->findChild<KLineEdit *>("kcfg_FileMask");
+  
+  msg = i18n("<qt>An incorrect setting has been found. You are now taken to the corresponding configuration page to fix it.</qt>");
+  
   if (file_mask && file_mask->text().trimmed().isEmpty())
   {
     KMessageBox::sorry(this, msg);
@@ -348,25 +286,16 @@ bool Smb4KConfigDialog::checkMountingPage()
     file_mask->setFocus();
     return false;
   }
-  else
-  {
-    // Do nothing
-  }
   
   KLineEdit *directory_mask = m_mounting->widget()->findChild<KLineEdit *>("kcfg_DirectoryMask");
   
   if (directory_mask && directory_mask->text().trimmed().isEmpty())
   {
     KMessageBox::sorry(this, msg);
-    setCurrentPage(m_samba);
+    setCurrentPage(m_mounting);
     directory_mask->setFocus();
     return false;
   }
-  else
-  {
-    // Do nothing
-  }
-#endif
   
   return true;
 }
@@ -374,323 +303,205 @@ bool Smb4KConfigDialog::checkMountingPage()
 
 bool Smb4KConfigDialog::checkSynchronizationPage()
 {
-  KUrlRequester *sync_prefix = m_synchronization->widget()->findChild<KUrlRequester *>("kcfg_RsyncPrefix");
+  //
+  // Get the config page 
+  // Since the config page is embedded into a scroll area, use findChild() here.
+  // 
+  Smb4KConfigPageSynchronization *configPage = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
   
-  QString msg = i18n("<qt>An incorrect setting has been found. You are now taken to the corresponding configuration page to fix it.</qt>");
-  
-  if (sync_prefix && sync_prefix->url().path().trimmed().isEmpty())
+  if (configPage)
   {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_synchronization);
+    //
+    // The error message
+    // 
+    QString errorMessage = i18n("<qt>An incorrect setting has been found. You are now taken to the corresponding configuration page to fix it.</qt>");
     
-    Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-    
-    if (sync_options)
+    // Find the tab number and the url requester
+    for (int i = 0; i < configPage->count(); i++)
     {
-      sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::CopyingTab);
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    sync_prefix->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  QCheckBox *max_delete = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UseMaximumDelete");
-  QSpinBox *max_delete_val = m_synchronization->widget()->findChild<QSpinBox *>("kcfg_MaximumDeleteValue");
-  
-  if ((max_delete && max_delete->isChecked()) && (max_delete_val && max_delete_val->value() == 0))
-  {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_synchronization);
-    
-    Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-    
-    if (sync_options)
-    {
-      sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::DelTransTab);
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    max_delete_val->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  QCheckBox *min_trans_size = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UseMinimalTransferSize");
-  QSpinBox *min_trans_size_val = m_synchronization->widget()->findChild<QSpinBox *>("kcfg_MinimalTransferSize");
-  
-  if ((min_trans_size && min_trans_size->isChecked()) && (min_trans_size_val && min_trans_size_val->value() == 0))
-  {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_synchronization);
-    
-    Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-    
-    if (sync_options)
-    {
-      sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::DelTransTab);
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    min_trans_size_val->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  QCheckBox *max_trans_size = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UseMaximalTransferSize");
-  QSpinBox *max_trans_size_val = m_synchronization->widget()->findChild<QSpinBox *>("kcfg_MaximalTransferSize");
-  
-  if ((max_trans_size && max_trans_size->isChecked()) && (max_trans_size_val && max_trans_size_val->value() == 0))
-  {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_synchronization);
-    
-    Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-    
-    if (sync_options)
-    {
-      sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::DelTransTab);
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    max_trans_size_val->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  QCheckBox *use_partial_directory = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UsePartialDirectory");
-  KUrlRequester *partial_directory = m_synchronization->widget()->findChild<KUrlRequester *>("kcfg_PartialDirectory");
-  
-  if ((use_partial_directory && use_partial_directory->isChecked()) &&
-      (partial_directory && partial_directory->url().path().trimmed().isEmpty()))
-  {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_synchronization);
-    
-    Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-    
-    if (sync_options)
-    {
-      sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::DelTransTab);
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    partial_directory->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  QCheckBox *use_exclude_pattern = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UseExcludePattern");
-  KLineEdit *exclude_pattern = m_synchronization->widget()->findChild<KLineEdit *>("kcfg_ExcludePattern");
-  
-  if ((use_exclude_pattern && use_exclude_pattern->isChecked()) &&
-      (exclude_pattern && exclude_pattern->text().trimmed().isEmpty()))
-  {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_synchronization);
-    
-    Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-    
-    if (sync_options)
-    {
-      sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::FilteringTab);
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    exclude_pattern->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  QCheckBox *use_exclude_file = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UseExcludeFrom");
-  KUrlRequester *exclude_file = m_synchronization->widget()->findChild<KUrlRequester *>("kcfg_ExcludeFrom");
-  
-  if ((use_exclude_file && use_exclude_file->isChecked()) &&
-      (exclude_file && exclude_file->url().path().trimmed().isEmpty()))
-  {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_synchronization);
-    
-    Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-    
-    if (sync_options)
-    {
-      sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::FilteringTab);
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    exclude_file->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  QCheckBox *use_include_pattern = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UseIncludePattern");
-  KLineEdit *include_pattern = m_synchronization->widget()->findChild<KLineEdit *>("kcfg_IncludePattern");
-  
-  if ((use_include_pattern && use_include_pattern->isChecked()) &&
-      (include_pattern && include_pattern->text().trimmed().isEmpty()))
-  {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_synchronization);
-    
-    Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-    
-    if (sync_options)
-    {
-      sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::FilteringTab);
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    include_pattern->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  QCheckBox *use_include_file = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UseIncludeFrom");
-  KUrlRequester *include_file = m_synchronization->widget()->findChild<KUrlRequester *>("kcfg_IncludeFrom");
-  
-  if ((use_include_file && use_include_file->isChecked()) &&
-      (include_file && include_file->url().path().trimmed().isEmpty()))
-  {
-    KMessageBox::sorry(this, msg);
-    setCurrentPage(m_synchronization);
-    
-    Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-    
-    if (sync_options)
-    {
-      sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::FilteringTab);
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    include_file->setFocus();
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  QCheckBox *make_backups = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_MakeBackups");
-  
-  if (make_backups && make_backups->isChecked())
-  {
-    QCheckBox *use_backup_suffix = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UseBackupSuffix");
-    KLineEdit *backup_suffix = m_synchronization->widget()->findChild<KLineEdit *>("kcfg_BackupSuffix");
-    
-    if ((use_backup_suffix && use_backup_suffix->isChecked()) &&
-        (backup_suffix && backup_suffix->text().trimmed().isEmpty()))
-    {
-      KMessageBox::sorry(this, msg);
-      setCurrentPage(m_synchronization);
+      // Synchronization prefix
+      KUrlRequester *syncPrefix = configPage->widget(i)->findChild<KUrlRequester *>("kcfg_RsyncPrefix");
       
-      Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-      
-      if (sync_options)
+      if (syncPrefix && (!syncPrefix->url().isValid() || syncPrefix->url().path().trimmed().isEmpty()))
       {
-        sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::AdvancedTab);
+        KMessageBox::sorry(this, errorMessage);
+        setCurrentPage(m_synchronization);
+        configPage->setCurrentIndex(i);
+        syncPrefix->setFocus();
+        return false;
       }
-      else
+    
+      // Backups
+      QCheckBox *makeBackups = configPage->widget(i)->findChild<QCheckBox *>("kcfg_MakeBackups");
+      QCheckBox *useBackupSuffix = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UseBackupSuffix");
+      KLineEdit *backupSuffix = configPage->widget(i)->findChild<KLineEdit *>("kcfg_BackupSuffix");
+      QCheckBox *useBackupDir = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UseBackupDirectory");
+      KUrlRequester *backupDir = configPage->widget(i)->findChild<KUrlRequester *>("kcfg_BackupDirectory");
+      
+      if (makeBackups && makeBackups->isChecked())
       {
-        // Do nothing
+        if (useBackupSuffix && useBackupSuffix->isChecked())
+        {
+          if (backupSuffix && backupSuffix->text().trimmed().isEmpty())
+          {
+            KMessageBox::sorry(this, errorMessage);
+            setCurrentPage(m_synchronization);
+            configPage->setCurrentIndex(i);
+            backupSuffix->setFocus();
+            return false;
+          }
+        }
+        
+        if (useBackupDir && useBackupDir->isChecked())
+        {
+          if (backupDir && (!backupDir->url().isValid() || backupDir->url().path().trimmed().isEmpty()))
+          {
+            KMessageBox::sorry(this, errorMessage);
+            setCurrentPage(m_synchronization);
+            configPage->setCurrentIndex(i);
+            backupDir->setFocus();
+            return false;
+          }
+        }
       }
       
-      backup_suffix->setFocus();
-      return false;
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    QCheckBox *use_backup_dir = m_synchronization->widget()->findChild<QCheckBox *>("kcfg_UseBackupDirectory");
-    KUrlRequester *backup_dir = m_synchronization->widget()->findChild<KUrlRequester *>("kcfg_BackupDirectory");
-    
-    if ((use_backup_dir && use_backup_dir->isChecked()) &&
-        (backup_dir && backup_dir->url().path().trimmed().isEmpty()))
-    {
-      KMessageBox::sorry(this, msg);
-      setCurrentPage(m_synchronization);
+      // Minimal transfer size
+      QCheckBox *useMinTransferSize = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UseMinimalTransferSize");
+      QSpinBox *minTransferSize = configPage->widget(i)->findChild<QSpinBox *>("kcfg_MinimalTransferSize");
       
-      Smb4KConfigPageSynchronization *sync_options = m_synchronization->widget()->findChild<Smb4KConfigPageSynchronization *>();
-      
-      if (sync_options)
+      if (useMinTransferSize && useMinTransferSize->isChecked())
       {
-        sync_options->setCurrentIndex(Smb4KConfigPageSynchronization::AdvancedTab);
+        if (minTransferSize && minTransferSize->value() == 0)
+        {
+          KMessageBox::sorry(this, errorMessage);
+          setCurrentPage(m_synchronization);
+          configPage->setCurrentIndex(i);
+          minTransferSize->setFocus();
+          return false;
+        }
       }
-      else
+
+      // Maximal transfer size
+      QCheckBox *useMaxTransferSize = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UseMaximalTransferSize");
+      QSpinBox *maxTransferSize = configPage->widget(i)->findChild<QSpinBox *>("kcfg_MaximalTransferSize");
+      
+      if (useMaxTransferSize && useMaxTransferSize->isChecked())
       {
-        // Do nothing
+        if (maxTransferSize && maxTransferSize->value() == 0)
+        {
+          KMessageBox::sorry(this, errorMessage);
+          setCurrentPage(m_synchronization);
+          configPage->setCurrentIndex(i);
+          maxTransferSize->setFocus();
+          return false;
+        }
       }
       
-      backup_dir->setFocus();
-      return false;
-    }
-    else
-    {
-      // Do nothing
+      // Partial directory
+      QCheckBox *usePartialDirectory = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UsePartialDirectory");
+      KUrlRequester *partialDirectory = configPage->widget(i)->findChild<KUrlRequester *>("kcfg_PartialDirectory");
+      
+      if (usePartialDirectory && usePartialDirectory->isChecked())
+      {
+        if (partialDirectory && (!partialDirectory->url().isValid() || partialDirectory->url().path().trimmed().isEmpty()))
+        {
+          KMessageBox::sorry(this, errorMessage);
+          setCurrentPage(m_synchronization);
+          configPage->setCurrentIndex(i);
+          partialDirectory->setFocus();
+          return false;
+        }
+      }
+      
+      // Exclude exclude
+      QCheckBox *useExcludePattern = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UseExcludePattern");
+      KLineEdit *excludePattern = configPage->widget(i)->findChild<KLineEdit *>("kcfg_ExcludePattern");
+      
+      if (useExcludePattern && useExcludePattern->isChecked())
+      {
+        if (excludePattern && excludePattern->text().trimmed().isEmpty())
+        {
+          KMessageBox::sorry(this, errorMessage);
+          setCurrentPage(m_synchronization);
+          configPage->setCurrentIndex(i);
+          excludePattern->setFocus();
+          return false;
+        }
+      }
+      
+      // Read exclude pattern from file
+      QCheckBox *useExcludeFrom = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UseExcludeFrom");
+      KUrlRequester *excludeFrom = configPage->widget(i)->findChild<KUrlRequester *>("kcfg_ExcludeFrom");
+      
+      if (useExcludeFrom && useExcludeFrom->isChecked())
+      {
+        if (excludeFrom && (!excludeFrom->url().isValid() || excludeFrom->url().path().trimmed().isEmpty()))
+        {
+          KMessageBox::sorry(this, errorMessage);
+          setCurrentPage(m_synchronization);
+          configPage->setCurrentIndex(i);
+          excludeFrom->setFocus();
+          return false;
+        }
+      }
+      
+      // Exclude exclude
+      QCheckBox *useIncludePattern = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UseIncludePattern");
+      KLineEdit *includePattern = configPage->widget(i)->findChild<KLineEdit *>("kcfg_IncludePattern");
+      
+      if (useIncludePattern && useIncludePattern->isChecked())
+      {
+        if (includePattern && includePattern->text().trimmed().isEmpty())
+        {
+          KMessageBox::sorry(this, errorMessage);
+          setCurrentPage(m_synchronization);
+          configPage->setCurrentIndex(i);
+          includePattern->setFocus();
+          return false;
+        }
+      }
+      
+      // Read exclude pattern from file
+      QCheckBox *useIncludeFrom = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UseIncludeFrom");
+      KUrlRequester *includeFrom = configPage->widget(i)->findChild<KUrlRequester *>("kcfg_IncludeFrom");
+      
+      if (useIncludeFrom && useIncludeFrom->isChecked())
+      {
+        if (includeFrom && (!includeFrom->url().isValid() || includeFrom->url().path().trimmed().isEmpty()))
+        {
+          KMessageBox::sorry(this, errorMessage);
+          setCurrentPage(m_synchronization);
+          configPage->setCurrentIndex(i);
+          includeFrom->setFocus();
+          return false;
+        }
+      }
+      
+      // Block size
+      QCheckBox *useFixedBlocksize = configPage->widget(i)->findChild<QCheckBox *>("kcfg_UseBlockSize");
+      QSpinBox *fixedBlocksize = configPage->widget(i)->findChild<QSpinBox *>("kcfg_BlockSize");
+      
+      if (useFixedBlocksize && useFixedBlocksize->isChecked())
+      {
+        if (fixedBlocksize && fixedBlocksize->value() == 0)
+        {
+          KMessageBox::sorry(this, errorMessage);
+          setCurrentPage(m_synchronization);
+          configPage->setCurrentIndex(i);
+          fixedBlocksize->setFocus();
+          return false;
+        }
+      }
+      
+      // NOTE: The is no need to check the following settings, because they may be empty or 0:
+      // - kcfg_UseCompressionLevel & kcfg_CompressionLevel
+      // - kcfg_UseSkipCompression & kcfg_SkipCompression
+      // - kcfg_UseBandwidthLimit & kcfg_BandwidthLimit
+      // - kcfg_UseMaximumDelete & kcfg_MaximumDeleteValue
+      // - kcfg_CustomFilteringRules
+      // - kcfg_UseChecksumSeed & kcfg_ChecksumSeed
     }
   }
-  else
-  {
-    // Do nothing
-  }
-  
-  // FIXME: Also check --block-size (kcfg_UseBlockSize & kcfg_BlockSize) and 
-  // --checksum-seed (kcfg_UseChecksumSeed & kcfg_ChecksumSeed), if necessary.
-  // However, I need more info on what values are needed ...
 
   return true;
 }
@@ -704,40 +515,18 @@ bool Smb4KConfigDialog::checkSettings()
   {
     return false;
   }
-  else
-  {
-    // Do nothing
-  }
-  
-  // Check Shares page
-  if (!checkSharesPage())
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
   
   // Check Mounting page
   if (!checkMountingPage())
   {
     return false;
   }
-  else
-  {
-    // Do nothing
-  }
   
   // Check Synchronization page
   if (!checkSynchronizationPage())
   {
     return false;
   }
-  else
-  {
-    // Do nothing
-  }
   
   return true;
 }
@@ -779,174 +568,135 @@ void Smb4KConfigDialog::reject()
 
 void Smb4KConfigDialog::slotLoadAuthenticationInformation()
 {
-  Smb4KConfigPageAuthentication *auth_options = m_authentication->widget()->findChild<Smb4KConfigPageAuthentication *>();
-  QList<Smb4KAuthInfo *> entries = Smb4KWalletManager::self()->walletEntries();
-  auth_options->insertWalletEntries(entries);
-  auth_options->displayWalletEntries();
+  //
+  // Get the Authentication config page
+  // 
+  Smb4KConfigPageAuthentication *authenticationPage = m_authentication->widget()->findChild<Smb4KConfigPageAuthentication *>();
+  
+  //
+  // Insert and display the wallet entries
+  // 
+  authenticationPage->insertWalletEntries(Smb4KWalletManager::self()->walletEntries());
 }
 
 
 void Smb4KConfigDialog::slotSaveAuthenticationInformation()
 {
-  Smb4KConfigPageAuthentication *auth_options = m_authentication->widget()->findChild<Smb4KConfigPageAuthentication *>();
+  //
+  // Get the Authentication config page
+  // 
+  Smb4KConfigPageAuthentication *authenticationPage = m_authentication->widget()->findChild<Smb4KConfigPageAuthentication *>();
   
-  if (auth_options->walletEntriesDisplayed())
+  //
+  // Save the authentication information to the wallet
+  // 
+  if (authenticationPage->walletEntriesDisplayed())
   {
-    QList<Smb4KAuthInfo *> entries = auth_options->getWalletEntries();
-    Smb4KWalletManager::self()->writeWalletEntries(entries);
-  }
-  else
-  {
-    // Do nothing
+    Smb4KWalletManager::self()->writeWalletEntries(authenticationPage->getWalletEntries());
   }
 }
 
 
 void Smb4KConfigDialog::slotSetDefaultLogin()
 {
-  Smb4KConfigPageAuthentication *auth_options = m_authentication->widget()->findChild<Smb4KConfigPageAuthentication *>();
+  //
+  // Get the Authentication config page
+  // 
+  Smb4KConfigPageAuthentication *authenticationPage = m_authentication->widget()->findChild<Smb4KConfigPageAuthentication *>();
   
-  if (!auth_options->undoRemoval())
+  //
+  // Create an authentication object for the default authentication information
+  // 
+  Smb4KAuthInfo authInfo;
+  
+  //
+  // Read the default authentication information
+  // 
+  Smb4KWalletManager::self()->readDefaultAuthInfo(&authInfo);
+
+  //
+  // Show the password dialog to enter or modify the default authentication
+  // information.
+  // 
+  QPointer<KPasswordDialog> dlg = new KPasswordDialog(this, KPasswordDialog::ShowUsernameLine);
+  dlg->setPrompt(i18n("Enter the default login information."));
+  dlg->setUsername(authInfo.userName());
+  dlg->setPassword(authInfo.password());
+    
+  if (dlg->exec() == KPasswordDialog::Accepted)
   {
-    Smb4KAuthInfo authInfo;
-    // We do not need to call useDefaultAuthInfo(), because 
-    // Smb4KWalletManager::readDefaultAuthInfo() will do this
-    // for us.
-    Smb4KWalletManager::self()->readDefaultAuthInfo(&authInfo);
-    
-    QPointer<KPasswordDialog> dlg = new KPasswordDialog(this, KPasswordDialog::ShowUsernameLine);
-    dlg->setPrompt(i18n("Enter the default login information."));
-    dlg->setUsername(authInfo.userName());
-    dlg->setPassword(authInfo.password());
-    
-    if (dlg->exec() == KPasswordDialog::Accepted)
-    {
-      authInfo.setUserName(dlg->username());
-      authInfo.setPassword(dlg->password());
+    //
+    // Save the authentication information to the wallet
+    // 
+    authInfo.setUserName(dlg->username());
+    authInfo.setPassword(dlg->password());
       
-      Smb4KWalletManager::self()->writeDefaultAuthInfo(&authInfo);
+    Smb4KWalletManager::self()->writeDefaultAuthInfo(&authInfo);
       
-      if (auth_options->walletEntriesDisplayed())
-      {
-        slotLoadAuthenticationInformation();
-      }
-      else
-      {
-        // Do nothing
-      }    
-    }
-    else
+    //
+    // Reload the list of authentication information
+    // 
+    if (authenticationPage->walletEntriesDisplayed())
     {
-      // Reset the checkbox.
-      auth_options->findChild<QCheckBox *>("kcfg_UseDefaultLogin")->setChecked(false);
+      slotLoadAuthenticationInformation();
     }
-    
-    delete dlg;
   }
   else
   {
-    // Do nothing
+    // 
+    // Discard the password dialog and reset the checkbox
+    // 
+    authenticationPage->findChild<QCheckBox *>("kcfg_UseDefaultLogin")->setChecked(false);
   }
+    
+  delete dlg;
 }
 
 
 void Smb4KConfigDialog::slotEnableApplyButton()
 {
-  // Check if we need to enable the Apply button.
+  // 
+  // Check if we need to enable the Apply button
+  // 
   bool enable = false;
   
-  // Check the wallet entries.
-  Smb4KConfigPageAuthentication *auth_options = m_authentication->widget()->findChild<Smb4KConfigPageAuthentication *>();
+  // 
+  // Check the wallet entries
+  // 
+  Smb4KConfigPageAuthentication *authenticationPage = m_authentication->widget()->findChild<Smb4KConfigPageAuthentication *>();
 
-  if (auth_options->walletEntriesMaybeChanged())
+  if (authenticationPage->walletEntriesMaybeChanged())
   {
-    QList<Smb4KAuthInfo *> old_wallet_entries = Smb4KWalletManager::self()->walletEntries();
-    QList<Smb4KAuthInfo *> new_wallet_entries = auth_options->getWalletEntries();
+    QList<Smb4KAuthInfo *> oldWalletEntries = Smb4KWalletManager::self()->walletEntries();
+    QList<Smb4KAuthInfo *> newWalletEntries = authenticationPage->getWalletEntries();
     
-    for (int i = 0; i < old_wallet_entries.size(); ++i)
+    for (Smb4KAuthInfo *oldEntry : oldWalletEntries)
     {
-      for (int j = 0; j < new_wallet_entries.size(); ++j)
+      for (Smb4KAuthInfo *newEntry : newWalletEntries)
       {
-        if (QString::compare(old_wallet_entries.at(i)->unc(),
-                               new_wallet_entries.at(j)->unc(),
-                               Qt::CaseInsensitive) == 0 &&
-             (QString::compare(old_wallet_entries.at(i)->workgroupName(),
-                                new_wallet_entries.at(j)->workgroupName(),
-                                Qt::CaseInsensitive) != 0 ||
-              QString::compare(old_wallet_entries.at(i)->userName(),
-                                new_wallet_entries.at(j)->userName(),
-                                Qt::CaseInsensitive) != 0 ||
-              QString::compare(old_wallet_entries.at(i)->password(),
-                                new_wallet_entries.at(j)->password(),
-                                Qt::CaseInsensitive) != 0))
+        if (QString::compare(oldEntry->url().toString(QUrl::RemovePort), newEntry->url().toString(QUrl::RemovePort), Qt::CaseInsensitive) == 0 /* leave the user info here */ &&
+            QString::compare(oldEntry->workgroupName(), newEntry->workgroupName(), Qt::CaseInsensitive) == 0)
         {
           enable = true;
           break;
         }
-        else
-        {
-          continue;
-        }
       }
       
       if (enable)
       {
         break;
       }
-      else
-      {
-        continue;
-      }
     }
   }
-  else
-  {
-    // Do nothing
-  }
   
-  // Check the custom settings.
-  Smb4KConfigPageCustomOptions *custom_options = m_custom_options->widget()->findChild<Smb4KConfigPageCustomOptions *>();
+  // 
+  // Check the custom options
+  // 
+  Smb4KConfigPageCustomOptions *customOptionsPage = m_custom_options->widget()->findChild<Smb4KConfigPageCustomOptions *>();
   
-  if (!enable && custom_options && custom_options->customSettingsMaybeChanged())
+  if (!enable && customOptionsPage && customOptionsPage->customSettingsMaybeChanged())
   {
-    QList<OptionsPtr> new_list = custom_options->getCustomOptions();
-    QList<OptionsPtr> old_list = Smb4KCustomOptionsManager::self()->customOptions();
-    
-    if (new_list.size() == old_list.size())
-    {
-      for (const OptionsPtr &no : new_list)
-      {
-        for (const OptionsPtr &oo : old_list)
-        {
-          if (!no->equals(oo.data()))
-          {
-            enable = true;
-            break;
-          }
-          else
-          {
-            // Do nothing
-          }
-        }
-        
-        if (enable)
-        {
-          break;
-        }
-        else
-        {
-          // Do nothing
-        }
-      }
-    }
-    else
-    {
-      enable = true;
-    }
-  }
-  else
-  {
-    // Do nothing
+    enable = true;
   }
 
   QPushButton *applyButton = buttonBox()->button(QDialogButtonBox::Apply);
@@ -955,63 +705,23 @@ void Smb4KConfigDialog::slotEnableApplyButton()
   {
     applyButton->setEnabled(enable);
   }
-  else
-  {
-    // Do nothing
-  }
-}
-
-
-void Smb4KConfigDialog::slotReloadCustomOptions()
-{
-  loadCustomOptions();
 }
 
 
 void Smb4KConfigDialog::slotCheckPage(KPageWidgetItem* /*current*/, KPageWidgetItem* before)
 {
-  if (before == m_user_interface)
-  {
-    // Nothing to do
-  }
-  else if (before == m_network)
+  if (before == m_network)
   {
     (void)checkNetworkPage();
   }
-  else if (before == m_shares)
-  {
-    (void)checkSharesPage();
-  }
-  else if (before == m_authentication)
-  {
-    // Do nothing
-  }
-  else if (before == m_samba)
-  {
-    // Do nothing
-  }
-#if !defined(UNSUPPORTED_PLATFORM)
   else if (before == m_mounting)
   {
     (void)checkMountingPage();
   }
-#endif
   else if (before == m_synchronization)
   {
     (void)checkSynchronizationPage();
   }
-  else if (before == m_custom_options)
-  {
-    // Do nothing
-  }
-  else if (before == m_profiles)
-  {
-    // Do nothing
-  }
-  else
-  {
-    // Do nothing
-  }
 }
 
 #include "smb4kconfigdialog.moc"
