@@ -1,8 +1,8 @@
 /***************************************************************************
-    The main window of Smb4K.
+    The main window of Smb4K
                              -------------------
     begin                : Di Jan 1 2008
-    copyright            : (C) 2008-2018 by Alexander Reinholdt
+    copyright            : (C) 2008-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -34,17 +34,15 @@
 #include <QActionGroup>
 #include <QLabel>
 #include <QProgressBar>
+#include <QDockWidget>
 
 // KDE includes
-#include <KParts/MainWindow>
-#include <KParts/Part>
-#include <KParts/PartManager>
+#include <KXmlGui/KXmlGuiWindow>
 
 // forward declarations
 class Smb4KSystemTray;
 class Smb4KPrintInfo;
 class Smb4KSynchronizationInfo;
-class Smb4KPreviewItem;
 
 /**
  * This is the main window of Smb4K. It provides the network browser, the
@@ -53,7 +51,7 @@ class Smb4KPreviewItem;
  * @author Alexander Reinholdt <alexander.reinholdt@kdemail.net>
  */
 
-class Smb4KMainWindow : public KParts::MainWindow
+class Smb4KMainWindow : public KXmlGuiWindow
 {
   Q_OBJECT
 
@@ -72,7 +70,12 @@ class Smb4KMainWindow : public KParts::MainWindow
     /**
      * Reimplemented from KMainWindow.
      */
-    bool queryClose();
+    bool queryClose() override;
+    
+    /**
+     * Reimplemented from KMainWindow
+     */
+    bool eventFilter(QObject *obj, QEvent *e) override;
 
   protected slots:
     /**
@@ -98,7 +101,7 @@ class Smb4KMainWindow : public KParts::MainWindow
      *
      * @param checked       TRUE if the action is checked
      */
-    void slotAddBookmark();
+    void slotAddBookmarks();
 
     /**
      * This slot is connected to the Smb4KWalletManager::initialized() signal.
@@ -106,29 +109,28 @@ class Smb4KMainWindow : public KParts::MainWindow
      * bar accordingly.
      */
     void slotWalletManagerInitialized();
-
+    
     /**
-     * This slot shows a status message according to the action performed by the 
-     * scanner as well as a busy bar. It is connected to the Smb4KScanner::aboutToStart() 
+     * This slot shows a busy bar and a status message according to the action performed by 
+     * the client. It is connected to the Smb4KClient::aboutToStart() signal.
+     *
+     * @param item          The network item
+     *
+     * @param process       The process
+     */
+    void slotClientAboutToStart(const NetworkItemPtr &item, int process);
+    
+    /**
+     * this slot shows a status message according to the action that was just finished by the 
+     * client and hides the status bar if appropriate. It is connected to the Smb4KClient::finished()
      * signal.
-     *
-     * @param item          The network item
-     *
-     * @param process       The process
-     */
-    void slotScannerAboutToStart(const NetworkItemPtr &item, int process);
-                                  
-    /**
-     * This shows a status message according to the action that was just finished by
-     * the scanner and hides the busy bar if appropriate. It is connected to the 
-     * Smb4KScanner::finished() signal.
      * 
      * @param item          The network item
      * 
      * @param process       The process
      */
-    void slotScannerFinished(const NetworkItemPtr &item, int process);
-                                   
+    void slotClientFinished(const NetworkItemPtr &item, int process);
+
     /**
      * This slot shows a status message according to the action performed by the 
      * mounter as well as a busy bar. It is connected to the Smb4KMounter::aboutToStart() 
@@ -161,38 +163,6 @@ class Smb4KMainWindow : public KParts::MainWindow
      */
     void slotVisualUnmountFeedback(const SharePtr &share);
                                   
-    /**
-     * This slot shows a status message as well as a busy bar. It is connected to the 
-     * Smb4KSearch::aboutToStart() signal.
-     *
-     * @param string        The search string
-     */
-    void slotSearchAboutToStart(const QString &string);
-    
-    /**
-     * This shows a status message and hides the busy bar if appropriate. It is 
-     * connected to the Smb4KSearch::finished() signal.
-     * 
-     * @param string        The search string
-     */
-   void slotSearchFinished(const QString &string);
-     
-    /**
-     * This slot shows a status message as well as a busy bar. It is connected to the 
-     * Smb4KPrint::aboutToStart() signal.
-     *
-     * @param printer       The remote printer
-     */
-    void slotPrintingAboutToStart(const SharePtr &printer);
-
-    /**
-     * This shows a status message and hides the busy bar if appropriate. It is 
-     * connected to the Smb4KPrint::finished() signal.
-     *
-     * @param printer       The remote printer
-     */
-    void slotPrintingFinished(const SharePtr &printer);
-
     /**
      * This slot shows a message according to the action performed by the synchronizer.
      * It is connected to the Smb4KSynchronizer::aboutToStart() signal.
@@ -209,41 +179,12 @@ class Smb4KMainWindow : public KParts::MainWindow
      */
     void slotSynchronizerFinished(const QString &dest);
 
-    /**
-     * This slot shows a message according to the action performed by the previewer.
-     * It is connected to the Smb4KPreviewer::aboutToStart() signal.
-     *
-     * @param share         The share
-     *
-     * @param url           The URL of the current location
-     */
-    void slotPreviewerAboutToStart(const SharePtr &share, const QUrl &url);
-
-    /**
-     * This slot shows a message according to the finished action that was reported
-     * by the previewer. It is connected to the Smb4KPreviewer::finished() signal.
-     *
-     * @param share         The share
-     *
-     * @param url           The URL of the current location
-     */
-    void slotPreviewerFinished(const SharePtr &share, const QUrl &url);
-
     /**
      * This slot hides the feedback icon in the status bar. It is connected to
      * a QTimer::singleShot() signal.
      */
     void slotEndVisualFeedback();
 
-    /**
-     * This slot is connected to the PartManager::activePartChanged() signal. It
-     * modifies the states of actions that are defined in the main window but 
-     * manage things in the parts.
-     *
-     * @param part          The now active KPart
-     */
-    void slotActivePartChanged(KParts::Part *part);
-
     /**
      * Enable/disable the "Add Bookmark" action
      */
@@ -264,15 +205,6 @@ class Smb4KMainWindow : public KParts::MainWindow
      * @param visible         If the dock widget is visible.
      */
     void slotSharesViewVisibilityChanged(bool visible);
-    
-    
-    /**
-     * This slot is connected to the visibilityChanged() signals of the network browser
-     * dock widget. It is used to get the tool bars right.
-     *
-     * @param visible         If the dock widget is visible.
-     */
-    void slotSearchDialogVisibilityChanged(bool visible);
 
   private:
     /**
@@ -315,6 +247,11 @@ class Smb4KMainWindow : public KParts::MainWindow
      */
     void setupMountIndicator();
     
+    /**
+     * Setup the dynamic action list
+     */
+    void setupDynamicActionList(QDockWidget *dock);
+    
     /**
      * This is the progress bar in the status bar.
      */
@@ -336,31 +273,17 @@ class Smb4KMainWindow : public KParts::MainWindow
      * The system tray widget
      */
     Smb4KSystemTray *m_system_tray_widget;
-
+    
     /**
-     * The network browser part
+     * This is the widget (embedded into a dock widget) that has 
+     * the focus. 
      */
-    KParts::Part *m_browser_part;
-
-    /**
-     * The search dialog part
-     */
-    KParts::Part *m_search_part;
-
-    /**
-     * The shares view
-     */
-    KParts::Part *m_shares_part;
-
-    /**
-     * The part manager
-     */
-    KParts::PartManager *m_manager;
+    QWidget *m_focusWidget;
 
     /**
      * Dock widgets action group;
      */
-    QActionGroup *m_dock_widgets;
+    QActionGroup *m_dockWidgets;
 };
 
 #endif
